"""Custom link component."""

from typing import Literal

from reflex.components.react_router.dom import ReactRouterLink, To
from reflex.vars.base import Var

from ...icons.hugeicon import hi
from ...utils.twmerge import cn

LiteralLinkVariant = Literal["primary", "secondary"]
LiteralLinkSize = Literal["xs", "sm", "md", "lg", "xl"]


class ClassNames:
    """Class names for the link component."""

    ROOT = "font-medium underline-offset-2 hover:underline w-fit group/link relative"
    ICON = "absolute top-1/2 -translate-y-1/2 right-[-1.25rem] group-hover/link:opacity-100 text-secondary-9 opacity-0"


LINK_VARIANTS: dict[str, dict[str, str]] = {
    "size": {
        "xs": "text-xs",
        "sm": "text-sm",
        "md": "text-md",
        "lg": "text-lg",
        "xl": "text-xl",
    },
    "variant": {
        "primary": "text-primary-11",
        "secondary": "text-secondary-11",
    },
}


class Link(ReactRouterLink):
    """Link component."""

    # The size of the link. Defaults to "sm".
    size: Var[LiteralLinkSize]

    # The variant of the link. Defaults to "secondary".
    variant: Var[LiteralLinkVariant]

    # Whether to show the icon. Defaults to False.
    show_icon: Var[bool]

    # The page to link to.
    to: Var[str | To]

    @classmethod
    def create(cls, *children, **props) -> ReactRouterLink:
        """Create the link component."""
        size = props.pop("size", "sm")
        cls.validate_size(size)
        variant = props.pop("variant", "secondary")
        cls.validate_variant(variant)
        render_component = props.pop("render_", None)
        show_icon = props.pop("show_icon", False)
        link_class_name = props.get("class_name", "")

        # Get the class name and children from the render component
        if render_component:
            children = list(getattr(render_component, "children", []))
            class_name = cn(
                getattr(render_component, "class_name", ""), link_class_name
            )
        else:
            children = list(children)
            size_class = LINK_VARIANTS["size"][size]
            variant_class = LINK_VARIANTS["variant"][variant]
            class_name = cn(
                f"{ClassNames.ROOT} {size_class} {variant_class}", link_class_name
            )

        if show_icon:
            children.append(hi("LinkSquare02Icon", class_name=ClassNames.ICON))

        props["class_name"] = class_name
        return super().create(*children, **props)

    @staticmethod
    def validate_variant(variant: LiteralLinkVariant):
        """Validate the link variant."""
        if variant not in LINK_VARIANTS["variant"]:
            available_variants = ", ".join(LINK_VARIANTS["variant"].keys())
            message = (
                f"Invalid variant: {variant}. Available variants: {available_variants}"
            )
            raise ValueError(message)

    @staticmethod
    def validate_size(size: LiteralLinkSize):
        """Validate the link size."""
        if size not in LINK_VARIANTS["size"]:
            available_sizes = ", ".join(LINK_VARIANTS["size"].keys())
            message = f"Invalid size: {size}. Available sizes: {available_sizes}"
            raise ValueError(message)

    def _exclude_props(self) -> list[str]:
        return [*super()._exclude_props(), "size", "variant", "show_icon", "render_"]


link = Link.create



"""Spinner component wrapper for react-spinners."""

import reflex as rx
from reflex.utils.imports import ImportVar


class Spinner(rx.Component):
    """React Spinner component."""

    library = "react-spinners"

    tag = "ClipLoader"

    color: rx.Var[str] | str = "var(--chart-1)"

    size: rx.Var[int]

    loading: rx.Var[bool]

    @classmethod
    def create(cls, spinner_type: str = "ClipLoader", **props):
        instance = super().create(**props)
        instance.tag = spinner_type
        return instance

    def add_imports(self):
        return {self.library: ImportVar(tag=self.tag, is_default=False)}


def spinner(spinner_type: str = "ClipLoader", **props):
    """Create a spinner. Types: ClipLoader, BeatLoader, CircleLoader, etc."""
    return Spinner.create(spinner_type, **props)



"""React CountUp component wrapper for react-countup."""

import reflex as rx


class CountUp(rx.Component):
    """CountUp component for animated number counting."""

    library = "react-countup"
    tag = "CountUp"
    is_default = True

    start: rx.Var[int | float]
    end: rx.Var[int | float]
    duration: rx.Var[int | float]
    decimals: rx.Var[int]
    decimal: rx.Var[str]
    prefix: rx.Var[str]
    suffix: rx.Var[str]
    separator: rx.Var[str]
    delay: rx.Var[int | float]
    enable_scroll_spy: rx.Var[bool]
    scroll_spy_delay: rx.Var[int]
    scroll_spy_once: rx.Var[bool]
    preserve_value: rx.Var[bool]
    use_easing: rx.Var[bool]
    easingFn: rx.Var[str]

    @classmethod
    def create(cls, **props):
        """Create a CountUp component.

        Args:
            **props: Component props

        Returns:
            The component instance.
        """
        return super().create(**props)


def count_up(**props) -> rx.Component:
    """Create an animated number counting component.

    NOTE: This uses react-countup package.
    Install with: npm install react-countup

    Args:
        start: Starting number (default: 0)
        end: Ending number (required)
        duration: Animation duration in seconds (default: 2)
        decimals: Number of decimal places (default: 0)
        decimal: Decimal character (default: ".")
        prefix: Text before number (e.g., "$")
        suffix: Text after number (e.g., "+", "%")
        separator: Thousands separator (default: ",")
        delay: Delay before animation starts in seconds (default: 0)
        enable_scroll_spy: Start animation when scrolled into view (default: False)
        scroll_spy_delay: Delay for scroll spy in ms (default: 0)
        scroll_spy_once: Only trigger scroll spy once (default: False)
        preserve_value: Preserve previous value on props change (default: False)
        use_easing: Use easing animation (default: True)
        **props: Additional component props

    Returns:
        The CountUp component.

    Example:
        count_up(end=1000, duration=2.5, prefix="$", separator=",")
    """
    return CountUp.create(**props)



"""Custom avatar component."""

from reflex.components.component import Component, ComponentNamespace
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent


class ClassNames:
    """Class names for avatar components."""

    ROOT = "shrink-0 inline-flex size-8 items-center justify-center overflow-hidden rounded-full align-middle text-base font-medium select-none"
    IMAGE = "size-full object-cover shrink-0"
    FALLBACK = "flex size-full items-center justify-center text-sm bg-muted"


class AvatarBaseComponent(BaseUIComponent):
    """Base component for avatar components."""

    library = f"{PACKAGE_NAME}/avatar"

    @property
    def import_var(self):
        """Return the import variable for the avatar component."""
        return ImportVar(tag="Avatar", package_path="", install=False)


class AvatarRoot(AvatarBaseComponent):
    """Displays a user's profile picture, initials, or fallback icon."""

    tag = "Avatar.Root"

    # The component to render
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the avatar root component."""
        props["data-slot"] = "avatar"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


class AvatarImage(AvatarBaseComponent):
    """The image to be displayed in the avatar."""

    tag = "Avatar.Image"

    # The image source URL
    src: Var[str]

    # Callback when loading status changes
    on_loading_status_change: EventHandler[passthrough_event_spec(str)]

    # The component to render
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the avatar image component."""
        props["data-slot"] = "avatar-image"
        cls.set_class_name(ClassNames.IMAGE, props)
        return super().create(*children, **props)


class AvatarFallback(AvatarBaseComponent):
    """Rendered when the image fails to load or when no image is provided."""

    tag = "Avatar.Fallback"

    # How long to wait before showing the fallback. Specified in milliseconds
    delay: Var[int]

    # The component to render
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the avatar fallback component."""
        props["data-slot"] = "avatar-fallback"
        cls.set_class_name(ClassNames.FALLBACK, props)
        return super().create(*children, **props)


class HighLevelAvatar(AvatarRoot):
    """High level wrapper for the Avatar component."""

    # The image source URL
    src: Var[str]

    # Image props
    _image_props = {"src", "on_loading_status_change", "render_"}

    # Fallback props
    _fallback_props = {"delay"}

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the avatar component."""
        # Extract props for each subcomponent
        image_props = {k: props.pop(k) for k in cls._image_props & props.keys()}
        fallback_props = {k: props.pop(k) for k in cls._fallback_props & props.keys()}

        fallback_content = props.pop("fallback", "")

        return AvatarRoot.create(
            AvatarImage.create(**image_props),
            AvatarFallback.create(fallback_content, **fallback_props),
            *children,
            **props,
        )


class Avatar(ComponentNamespace):
    """Namespace for Avatar components."""

    root = staticmethod(AvatarRoot.create)
    image = staticmethod(AvatarImage.create)
    fallback = staticmethod(AvatarFallback.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelAvatar.create)


avatar = Avatar()



import os
import re
import src.docs.constants as constants


from typing import List
from src.docs.parser import DocParser
from src.utils.frontmatter import parse_frontmatter


parser = DocParser(dynamic_load_dirs=[constants.DOCS_LIBRARY_ROOT])


def generate_docs_library() -> List[constants.DocDataStruct]:
    docs = []
    dev_mode = os.environ.get("SAPPHIREUI_DEV_MODE") == "true"

    if not constants.DOCS_BASE_DIR.exists():
        print(f"Warning: Docs base directory not found: {constants.DOCS_BASE_DIR}")
        return []

    # Create a mapping from URL slug to file path for all markdown files
    all_md_files = list(constants.DOCS_BASE_DIR.glob("**/*.md"))
    slug_to_path_map = {}
    for md_file in all_md_files:
        relative_path = md_file.relative_to(constants.DOCS_BASE_DIR)
        slug = "/".join(
            [part.replace("_", "-") for part in relative_path.with_suffix("").parts]
        )
        slug_to_path_map[slug] = md_file

    md_files_to_process = []
    if dev_mode:
        print("--- Development Mode Enabled ---")
        pages_str = os.environ.get("SAPPHIREUI_DEV_PAGES", "")
        if not pages_str:
            print("Warning: SAPPHIREUI_DEV_PAGES is not set. Loading no pages.")
            return []

        page_slugs = [slug.strip() for slug in pages_str.split(",")]
        print(f"Loading specified pages: {page_slugs}")
        print("Loading specified URLs:")
        for slug in page_slugs:
            print(f"http://localhost:3000/docs/{slug}")
            if slug in slug_to_path_map:
                md_files_to_process.append(slug_to_path_map[slug])
            else:
                print(f"Warning: Markdown file not found for slug: {slug}")
    else:
        md_files_to_process = all_md_files

    for md_file_path in md_files_to_process:
        relative_path = md_file_path.relative_to(constants.DOCS_BASE_DIR)
        url_path_parts = [part.replace("_", "-") for part in relative_path.parts]
        url_path = "docs/" + "/".join(url_path_parts).replace(".md", "")

        # Read the markdown content
        with open(md_file_path, "r") as f:
            md_content = f.read()

        __, md_content = parse_frontmatter(md_content)

        # Extract headings for TOC from THIS file's content
        toc_data = []
        for match in re.finditer(r"^(#{1,2})\s+(.+)$", md_content, re.MULTILINE):
            level = len(match.group(1))  # Count the # characters (1-2)
            heading_text = match.group(2).strip()  # Get the heading text

            toc_data.append(
                {
                    "text": heading_text,
                    "id": heading_text,
                    "level": level,
                }
            )

        # Create the doc component (no need for inner function)
        doc = constants.DocDataStruct(
            url=url_path,
            component=parser.parse_and_render(md_content),
            table_of_content=toc_data,
        )

        docs.append(doc)

    return docs



"""Checkbox component from base-ui components."""

from reflex.components.component import ComponentNamespace
from reflex.components.el import Label
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent
from ...icons.hugeicon import hi
from ...utils.twmerge import cn


class ClassNames:
    """Class names for the checkbox component."""

    ROOT = "flex size-4 items-center justify-center rounded-[4px] data-[checked]:bg-primary data-[unchecked]:border data-[unchecked]:border-input data-[disabled]:cursor-not-allowed data-[disabled]:border data-[disabled]:border-input/50 data-[disabled]:bg-secondary hover:bg-secondary transition-colors cursor-default"
    INDICATOR = "flex text-primary-foreground data-[unchecked]:hidden data-[disabled]:text-secondary-foreground/50"
    LABEL = "text-sm text-secondary-foreground font-medium flex items-center gap-2"
    CONTAINER = "flex flex-row items-center gap-2"


class CheckboxBaseComponent(BaseUIComponent):
    """Base component for checkbox components."""

    library = f"{PACKAGE_NAME}/checkbox"

    @property
    def import_var(self):
        """Return the import variable for the checkbox component."""
        return ImportVar(tag="Checkbox", package_path="", install=False)


class CheckboxRoot(CheckboxBaseComponent):
    """The root checkbox component."""

    tag = "Checkbox.Root"

    # Whether the checkbox is initially ticked. To render a controlled checkbox, use the checked prop instead. Defaults to False.
    default_checked: Var[bool]

    # Whether the checkbox is currently ticked. To render an uncontrolled checkbox, use the default_checked prop instead.
    checked: Var[bool]

    # Event handler called when the checkbox is ticked or unticked.
    on_checked_change: EventHandler[passthrough_event_spec(bool, dict)]

    # Whether the checkbox is in a mixed state: neither ticked, nor unticked. Defaults to False.
    indeterminate: Var[bool]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # Whether the checkbox is required. Defaults to False.
    required: Var[bool]

    # Identifies the field when a form is submitted.
    name: Var[str]

    # The value of the selected checkbox.
    value: Var[str]

    # Whether the component renders a native <button> element when replacing it via the render prop. Set to false if the rendered element is not a button (e.g. <div>). Defaults to True.
    native_button: Var[bool]

    # Whether the checkbox controls a group of child checkboxes. Must be used in a Checkbox Group. Defaults to False.
    parent: Var[bool]

    # Whether the user should be unable to tick or untick the checkbox. Defaults to False.
    read_only: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the checkbox root component."""
        props["data-slot"] = "checkbox"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


class CheckboxIndicator(CheckboxBaseComponent):
    """The indicator that shows whether the checkbox is checked."""

    tag = "Checkbox.Indicator"

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the checkbox indicator component."""
        if len(children) == 0:
            children = (hi("Tick02Icon", size=14),)
        props["data-slot"] = "checkbox-indicator"
        cls.set_class_name(ClassNames.INDICATOR, props)
        return super().create(*children, **props)


class HighLevelCheckbox(CheckboxRoot):
    """High level wrapper for the Checkbox component."""

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create a high level checkbox component.

        Args:
            *children: The content of the checkbox.
            **props: Additional properties to apply to the checkbox component.

        Returns:
            The checkbox component and its indicator.
        """
        class_name = props.pop("class_name", "")
        if label := props.pop("label", None):
            return Label.create(  # pyright: ignore[reportReturnType]
                CheckboxRoot.create(
                    CheckboxIndicator.create(),
                    *children,
                    **props,
                ),
                label,
                class_name=cn(ClassNames.LABEL, class_name),
            )
        return CheckboxRoot.create(
            CheckboxIndicator.create(),
            *children,
            **props,
            class_name=class_name,
        )


class Checkbox(ComponentNamespace):
    """Namespace for Checkbox components."""

    root = staticmethod(CheckboxRoot.create)
    indicator = staticmethod(CheckboxIndicator.create)
    high_level = staticmethod(HighLevelCheckbox.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelCheckbox.create)


checkbox = Checkbox()



import reflex as rx

from ...base_ui.components.base.button import button


def button_size_examples():
    return rx.el.div(
        button("Small", size="sm"),
        button("Default", size="default"),
        button("Large", size="lg"),
        class_name="flex items-center gap-3",
    )


def button_default_example():
    return button("Default", variant="default")


def button_outline_example():
    return button("Outline", variant="outline")


def button_secondary_example():
    return button("Secondary", variant="secondary")


def button_ghost_example():
    return button("Ghost", variant="ghost")


def button_destructive_example():
    return button("Destructive", variant="destructive")


def button_link_example():
    return button("Link", variant="link")


def button_icon_examples():
    return (
        button(rx.icon("mail", class_name="size-4"), variant="outline", size="icon-sm"),
    )



"""Set of custom icons."""

from reflex.components.component import Component, memo
from reflex.components.el import svg
from reflex.vars.base import Var

from ..utils.twmerge import cn


@memo
def spinner_component(
    class_name: str | Var[str] = "",
) -> Component:
    """Create a spinner SVG icon.

    Args:
        class_name: The class name of the spinner.

    Returns:
        The spinner SVG icon.

    """
    return svg(
        svg.path(
            opacity="0.2",
            d="M14.66 8a6.666 6.666 0 1 1-13.333 0 6.666 6.666 0 0 1 13.333 0Z",
            stroke="currentColor",
            stroke_width="1.5",
        ),
        svg.path(
            d="M13.413 11.877A6.666 6.666 0 1 1 10.26 1.728",
            stroke="currentColor",
            stroke_width="1.5",
        ),
        xmlns="http://www.w3.org/2000/svg",
        custom_attrs={"viewBox": "0 0 16 16"},
        class_name=cn("animate-spin size-4 fill-none", class_name),
    )


spinner = spinner_component


@memo
def select_arrow_icon(
    class_name: str | Var[str] = "",
) -> Component:
    """A select arrow SVG icon."""
    return svg(
        svg.path(
            d="M4.99902 10.0003L7.99967 13.0003L10.999 10.0003M4.99902 6.00033L7.99967 3.00033L10.999 6.00033",
            stroke="currentColor",
            stroke_width="1.5",
            stroke_linecap="round",
            stroke_linejoin="round",
        ),
        xmlns="http://www.w3.org/2000/svg",
        custom_attrs={"viewBox": "0 0 16 16"},
        class_name=cn("size-4 fill-none", class_name),
    )


select_arrow = select_arrow_icon


@memo
def arrow_svg_component(class_name: str | Var[str] = "") -> Component:
    """Create a tooltip arrow SVG icon.

    The arrow SVG icon.
    """
    return svg(
        svg.path(
            d="M9.66437 2.60207L4.80758 6.97318C4.07308 7.63423 3.11989 8 2.13172 8H0V9H20V8H18.5349C17.5468 8 16.5936 7.63423 15.8591 6.97318L11.0023 2.60207C10.622 2.2598 10.0447 2.25979 9.66437 2.60207Z",
            class_name=cn("fill-secondary-12", class_name),
        ),
        svg.path(
            d="M10.3333 3.34539L5.47654 7.71648C4.55842 8.54279 3.36693 9 2.13172 9H0V8H2.13172C3.11989 8 4.07308 7.63423 4.80758 6.97318L9.66437 2.60207C10.0447 2.25979 10.622 2.2598 11.0023 2.60207L15.8591 6.97318C16.5936 7.63423 17.5468 8 18.5349 8H20V9H18.5349C17.2998 9 16.1083 8.54278 15.1901 7.71648L10.3333 3.34539Z",
            class_name="fill-none",
        ),
        width="20",
        height="10",
        xmlns="http://www.w3.org/2000/svg",
        custom_attrs={"viewBox": "0 0 20 10"},
        fill="none",
    )


arrow_svg = arrow_svg_component



import reflex as rx
from typing import Optional, Union


def input_with_addons(
    *children,
    placeholder: str = "",
    prefix: Optional[Union[str, "rx.Component"]] = None,
    suffix: Optional[Union[str, "rx.Component"]] = None,
    input_type: str = "text",
    class_name: str = "",
    **props,
):
    children = list(children)

    if prefix:
        if isinstance(prefix, str):
            prefix = rx.text(
                prefix,
                class_name="text-[var(--muted-foreground)] text-sm font-medium pl-2 select-none pointer-events-none",
            )
        children.insert(0, prefix)

    children.append(
        rx.el.input(
            type=input_type,
            placeholder=placeholder,
            class_name=(
                "flex-1 bg-transparent border-0 outline-none "
                "text-[var(--foreground)] placeholder:text-[var(--muted-foreground)] "
                "px-2 py-2 text-sm "
                + ("pl-2 " if prefix else "")
                + ("pr-2 " if suffix else "")
            ),
            **props,
        )
    )

    if suffix:
        if isinstance(suffix, str):
            suffix = rx.text(
                suffix,
                class_name="text-[var(--muted-foreground)] text-sm font-medium pr-2 select-none pointer-events-none",
            )
        children.append(suffix)

    return rx.box(
        *children,
        class_name=(
            "flex items-center w-full h-9 "
            "bg-transparent border border-[var(--input)] dark:bg-[var(--input)]/30 rounded-[var(--radius)] shadow-xs "
            "focus-within:border-[var(--ring)] focus-within:ring-[var(--ring)]/50 focus-within:ring-[3px] "
            "transition-[color,box-shadow] " + class_name
        ),
    )


def textarea_with_footer(
    placeholder: str = "",
    footer_text: Optional[str] = None,
    class_name: str = "",
    **props,
):
    children = [
        rx.el.textarea(
            placeholder=placeholder,
            class_name=(
                "flex-1 bg-transparent border-0 outline-none resize-none "
                "text-[var(--foreground)] placeholder:text-[var(--muted-foreground)] placeholder:text-sm "
                "px-3 py-3 text-sm " + ("pb-2 " if footer_text else "")
            ),
            **props,
        )
    ]

    if footer_text:
        children.append(
            rx.text(
                footer_text,
                class_name="text-[var(--muted-foreground)] text-xs px-3 pb-3 pt-0 select-none pointer-events-none",
            )
        )

    return rx.box(
        *children,
        class_name=(
            "flex flex-col w-full "
            "bg-transparent border border-[var(--input)] dark:bg-[var(--input)]/30 rounded-[var(--radius)] shadow-xs "
            "focus-within:border-[var(--ring)] focus-within:ring-[var(--ring)]/50 focus-within:ring-[3px] "
            "transition-[color,box-shadow] " + class_name
        ),
    )



"""Merge Tailwind CSS classes utility."""

from reflex.utils.imports import ImportVar
from reflex.vars import FunctionVar, Var
from reflex.vars.base import VarData


def cn(
    *classes: Var | str | tuple | list | None,
) -> Var:
    """Merge Tailwind CSS classes. Accepts strings, Vars, lists, or tuples.

    Args:
        *classes: Any number of class strings, Vars, tuples, or lists.

    Returns:
        Var: A Var representing the merged classes string.

    """
    return (
        Var(
            "cn",
            _var_data=VarData(imports={"clsx-for-tailwind": ImportVar(tag="cn")}),
        )
        .to(FunctionVar)
        .call(*classes)
        .to(str)
    )



import reflex as rx

tooltip = {
    "is_animation_active": False,
    "separator": "",
    "cursor": False,
    "item_style": {
        "color": "currentColor",
        "display": "flex",
        "paddingBottom": "0px",
        "justifyContent": "space-between",
        "textTransform": "capitalize",
    },
    "label_style": {
        "color": rx.color("slate", 10),
        "fontWeight": "500",
    },
    "content_style": {
        "background": rx.color_mode_cond("oklch(0.97 0.00 0)", "oklch(0.14 0.00 286)"),
        "borderColor": rx.color("slate", 5),
        "borderRadius": "5px",
        "fontFamily": "IBM Plex Mono,ui-monospace,monospace",
        "fontSize": "0.875rem",
        "lineHeight": "1.25rem",
        "fontWeight": "500",
        "letterSpacing": "-0.01rem",
        "minWidth": "8rem",
        "width": "175px",
        "padding": "0.375rem 0.625rem ",
        "position": "relative",
    },
}


def info(title: str, size: str, subtitle: str, align: str):
    return rx.vstack(
        rx.heading(title, size=size, weight="bold"),
        rx.text(subtitle, size="1", color=rx.color("slate", 11), weight="medium"),
        spacing="1",
        align=align,
    )


def get_tooltip():
    """Standard tooltip for all charts."""
    return rx.recharts.graphing_tooltip(**tooltip)


def get_cartesian_grid():
    """Standard cartesian grid for charts."""
    return rx.recharts.cartesian_grid(
        horizontal=True, vertical=False, class_name="opacity-25"
    )


def get_x_axis(data_key: str):
    """Standard X axis configuration."""
    return rx.recharts.x_axis(
        data_key=data_key,
        axis_line=False,
        tick_size=10,
        tick_line=False,
        custom_attrs={"fontSize": "12px"},
        interval="preserveStartEnd",
    )



import reflex as rx

from src.templates.sidebar import sidebar
from src.docs.library.base_ui.components.base.button import button


def drawer():
    return rx.drawer.root(
        rx.drawer.trigger(
            button(rx.icon(tag="menu", size=13), variant="ghost", size="sm"),
        ),
        rx.drawer.portal(
            rx.drawer.content(
                sidebar(in_drawer=True),
                width="100%",
                top="3.5rem",
                right="0",
                height="calc(100% - 3.5rem)",
                background=rx.color_mode_cond(
                    "oklch(1 0 0 / 0.95)", "oklch(0.145 0 0 / 0.95)"
                ),
            ),
        ),
        direction="left",
    )



import reflex as rx
from src.docs.library.charts.util import (
    get_tooltip,
    get_cartesian_grid,
)


def barchart_v8():
    categories = ["Successful", "Refunded"]
    EUROPE = [
        {"date": f"{month} 23", "Successful": successful, "Refunded": refunded}
        for month, successful, refunded in zip(
            [
                "Jan",
                "Feb",
                "Mar",
                "Apr",
                "May",
                "Jun",
                "Jul",
                "Aug",
                "Sep",
                "Oct",
                "Nov",
                "Dec",
            ],
            [12, 24, 48, 24, 34, 26, 12, 38, 23, 20, 24, 21],
            [0, 1, 4, 2, 0, 0, 0, 2, 1, 0, 0, 8],
        )
    ]

    ASIA = [
        {"date": f"{month} 23", "Successful": successful, "Refunded": refunded}
        for month, successful, refunded in zip(
            [
                "Jan",
                "Feb",
                "Mar",
                "Apr",
                "May",
                "Jun",
                "Jul",
                "Aug",
                "Sep",
                "Oct",
                "Nov",
                "Dec",
            ],
            [31, 32, 44, 23, 35, 48, 33, 38, 41, 39, 32, 19],
            [1, 2, 3, 2, 1, 1, 1, 3, 2, 1, 1, 5],
        )
    ]

    def create_chart(data: list[dict[str, str | int]]):
        return rx.recharts.bar_chart(
            get_cartesian_grid(),
            rx.foreach(
                categories,
                lambda key, index: rx.recharts.bar(
                    data_key=key,
                    fill=f"var(--chart-{index + 1})",
                    stack_id="_",
                ),
            ),
            rx.recharts.x_axis(
                interval=10,
                data_key="date",
                tick_size=10,
                class_name="text-xs font-semibold",
                axis_line=False,
                tick_line=False,
            ),
            get_tooltip(),
            data=data,
            width="100%",
            height=250,
            bar_size=25,
        )

    return rx.box(
        rx.text("Online Transactions", class_name="text-md font-semibold pb-3"),
        rx.tabs.root(
            rx.tabs.list(
                rx.tabs.trigger(
                    rx.text("Europe", class_name="text-sm font-semibold"),
                    flex="1",
                    value="1",
                ),
                rx.tabs.trigger(
                    rx.text("Asia", class_name="text-sm font-semibold"),
                    flex="1",
                    value="2",
                ),
            ),
            rx.tabs.content(create_chart(EUROPE), value="1", margin_top="-5px"),
            rx.tabs.content(create_chart(ASIA), value="2", margin_top="-5px"),
            default_value="1",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



import os
import glob

import src.docs.constants as constants
from src.utils.frontmatter import parse_frontmatter


# --- Method: Generate doc routes/urls ---
def generate_doc_routes(section_folder, base_path) -> list[dict]:
    """
    Generates routes for a documentation section by recursively reading
    frontmatter from markdown files.

    Args:
        section_folder: The folder name inside 'docs/' (e.g., 'getting_started').
        base_path: The base URL path for the routes (e.g., 'docs/getting-started/').

    Returns:
        A list of route dictionaries, sorted by the 'order' in metadata.
    """
    routes = []
    docs_path = f"{constants.DOCS_BASE_DIR}/{section_folder}"
    search_path = os.path.join(docs_path, "**/*.md")

    md_files = glob.glob(search_path, recursive=True)

    if not md_files:
        print(f"Warning: No markdown files found in '{docs_path}'")
        return []

    for file_path in md_files:
        try:
            with open(file_path, "r", encoding="utf-8") as f:
                content = f.read()
        except FileNotFoundError:
            continue

        metadata, _ = parse_frontmatter(content)

        if not metadata or "title" not in metadata:
            continue

        # Create a URL slug from the file path relative to the section folder.
        relative_path = os.path.relpath(file_path, docs_path)
        path_slug = relative_path.replace(".md", "").replace("_", "-")

        route_info = {
            "title": metadata["title"],
            "url": f"{base_path}{path_slug}",  # Will include docs/ prefix
            "order": metadata.get("order", 0),
        }

        routes.append(route_info)

    routes.sort(key=lambda x: x["order"])

    return routes


# --- Static: Each generation corresponds to a file in the docs/ folder ---
GET_STARTED_URLS = generate_doc_routes("getting_started", "docs/getting-started/")
BASE_UI_COMPONENTS = sorted(
    generate_doc_routes("components", "docs/components/"), key=lambda x: x["title"]
)
CHARTS_URLS = sorted(
    generate_doc_routes("charts", "docs/charts/"), key=lambda x: x["title"]
)
WRAPPED_COMPONENTS_URLS = generate_doc_routes(
    "wrapped_components", "docs/wrapped-components/"
)
JS_INTEGRATIONS_URLS = generate_doc_routes(
    "javascript_integrations", "docs/javascript-integrations/"
)



import reflex as rx


def doughnutchart_v1():
    data = [
        {"browser": "chrome", "visitors": 275},
        {"browser": "safari", "visitors": 200},
        {"browser": "firefox", "visitors": 187},
        {"browser": "edge", "visitors": 173},
        {"browser": "other", "visitors": 90},
    ]

    return rx.el.div(
        rx.recharts.pie_chart(
            rx.recharts.pie(
                rx.foreach(
                    ["red", "blue", "green", "amber", "purple"],
                    lambda color, index: rx.recharts.cell(
                        fill="var(--chart-2)", class_name=f"theme-{color}"
                    ),
                ),
                data=data,
                data_key="visitors",
                name_key="browser",
                stroke="0",
                inner_radius=90,
                custom_attrs={"paddingAngle": 3, "cornerRadius": 5},
            ),
            width="100%",
            height=350,
            class_name="w-[100%] [&_.recharts-tooltip-item-separator]:w-full",
        ),
        rx.hstack(
            rx.foreach(
                [
                    ["Chrome", "red"],
                    ["Safari", "blue"],
                    ["Firefox", "green"],
                    ["Edge", "amber"],
                    ["Other", "purple"],
                ],
                lambda key: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=rx.color(key[1])),
                    rx.text(
                        key[0],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full justify-center flex-wrap",
        ),
        class_name="flex flex-col size-full relative",
    )



"""Base UI component."""

from .component import CoreComponent

PACKAGE_NAME = "@base-ui-components/react"
PACKAGE_VERSION = "1.0.0-beta.4"


class BaseUIComponent(CoreComponent):
    """Base UI component."""

    lib_dependencies: list[str] = [f"{PACKAGE_NAME}@{PACKAGE_VERSION}"]



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
    get_cartesian_grid,
)


def areachart_v5():
    import datetime
    import random
    from reflex.experimental import ClientStateVar

    start_date = datetime.date(2024, 4, 1)
    data = [
        {
            "date": (start_date + datetime.timedelta(days=i)).strftime("%b %d"),
            "desktop": random.randint(80, 500),
            "mobile": random.randint(100, 550),
        }
        for i in range(91)
    ]

    SelectedRange = ClientStateVar.create("area_selected", data)

    def gradient(id_: str, color: str):
        return rx.el.svg.linear_gradient(
            rx.el.svg.stop(stop_color=f"var(--{color})", offset="5%", stop_opacity=0.8),
            rx.el.svg.stop(
                stop_color=f"var(--{color})", offset="95%", stop_opacity=0.1
            ),
            x1=0,
            x2=0,
            y1=0,
            y2=1,
            id=id_,
        )

    def area(data_key: str, color: str):
        return rx.recharts.area(
            data_key=data_key,
            fill=f"url(#{data_key})",
            stack_id="a",
            stroke=f"var(--{color})",
            animation_easing="linear",
        )

    select_options = [
        ("Last 3 Months", data),
        ("Last 30 Days", data[-30:]),
        ("Last 7 Days", data[-7:]),
    ]

    return rx.box(
        rx.hstack(
            info(
                "Area Chart - Dynamic",
                "3",
                "Showing total visitors for the last 6 months",
                "start",
            ),
            rx.el.select(
                *[
                    rx.el.option(label, on_click=SelectedRange.set_value(value))
                    for label, value in select_options
                ],
                default_value="Last 3 Months",
                bg=rx.color("gray", 2),
                border=f"1px solid {rx.color('gray', 4)}",
                class_name="relative flex items-center whitespace-nowrap justify-center gap-2 py-2 rounded-lg shadow-sm px-3",
            ),
            align="center",
            justify="between",
            width="100%",
            wrap="wrap",
        ),
        rx.recharts.area_chart(
            rx.el.svg.defs(
                gradient("desktop", "chart-1"),
                gradient("mobile", "chart-2"),
            ),
            get_tooltip(),
            get_cartesian_grid(),
            area("mobile", "chart-2"),
            area("desktop", "chart-1"),
            rx.recharts.x_axis(
                data_key="date",
                axis_line=False,
                min_tick_gap=32,
                tick_size=10,
                tick_line=False,
                custom_attrs={"fontSize": "12px"},
                interval="preserveStartEnd",
            ),
            data=SelectedRange.value,
            width="100%",
            height=280,
        ),
        info("Trending up by 5.2% this month", "2", "January - June 2024", "start"),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
    get_cartesian_grid,
    get_x_axis,
)


def areachart_v9():
    data = [
        {"month": "Jan", "desktop": 186},
        {"month": "Feb", "desktop": 305},
        {"month": "Mar", "desktop": 237},
        {"month": "Apr", "desktop": 73},
        {"month": "May", "desktop": 209},
        {"month": "Jun", "desktop": 214},
    ]

    def gradient(id_: str, color: str):
        return rx.el.svg.linear_gradient(
            rx.el.svg.stop(stop_color=f"var(--{color})", offset="5%", stop_opacity=0.8),
            rx.el.svg.stop(
                stop_color=f"var(--{color})", offset="95%", stop_opacity=0.1
            ),
            x1=0,
            x2=0,
            y1=0,
            y2=1,
            id=id_,
        )

    return rx.box(
        info(
            "Area Chart - Step with Gradient",
            "3",
            "Showing total visitors for the last 6 months",
            "start",
        ),
        rx.recharts.area_chart(
            rx.el.svg.defs(
                gradient("desktop", "chart-1"),
            ),
            get_tooltip(),
            get_cartesian_grid(),
            rx.recharts.area(
                data_key="desktop",
                fill="url(#desktop)",
                stroke="var(--chart-1)",
                stroke_width=2,
                type_="step",
                is_animation_active=False,
            ),
            get_x_axis("month"),
            data=data,
            width="100%",
            height=250,
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "January - June 2024",
            "start",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



"""
Script to sync components from reflex-ui repo to local UI library.

This script:
1. Clones/updates the reflex-ui repo in a cache directory
2. Copies necessary files (utils, base components, and all component files)
3. Rewrites imports to use relative imports
"""

import re
import subprocess
from pathlib import Path
from typing import List

# Configuration
REPO_URL = "https://github.com/reflex-dev/reflex-ui"
CACHE_DIR = Path(".reflex_ui_cache")
LOCAL_UI_PATH = Path("src/docs/library/base_ui")

# Source paths in the reflex-ui repo
SOURCE_UTILS = "reflex_ui/utils/twmerge.py"
SOURCE_COMPONENTS_DIR = "reflex_ui/components"
SOURCE_BASE_FILES = ["base_ui.py", "component.py"]
SOURCE_BASE_COMPONENTS = "reflex_ui/components/base"


def run_command(cmd: List[str], cwd: Path = None) -> bool:
    """Run a shell command and return success status."""
    try:
        # result = subprocess.run(
        #     cmd, cwd=cwd, capture_output=True, text=True, check=True
        # )
        return True
    except subprocess.CalledProcessError as e:
        print(f"Error running command: {' '.join(cmd)}")
        print(f"Error: {e.stderr}")
        return False


def clone_or_update_repo() -> bool:
    """Clone the repo if it doesn't exist, or pull latest changes if it does."""
    if CACHE_DIR.exists():
        print(f"Cache directory exists at {CACHE_DIR}")
        print("Checking for updates...")

        # Check if there are any remote changes
        if not run_command(["git", "fetch"], cwd=CACHE_DIR):
            return False

        # Check if local is behind remote
        result = subprocess.run(
            ["git", "rev-list", "--count", "HEAD..origin/main"],
            cwd=CACHE_DIR,
            capture_output=True,
            text=True,
        )

        commits_behind = result.stdout.strip()
        if commits_behind and commits_behind != "0":
            print(f"Repository is {commits_behind} commits behind. Pulling updates...")
            if not run_command(["git", "pull"], cwd=CACHE_DIR):
                return False
            print("Repository updated successfully!")
        else:
            print("Repository is up to date. Skipping clone/pull.")
    else:
        print(f"Cloning repository to {CACHE_DIR}...")
        if not run_command(["git", "clone", REPO_URL, str(CACHE_DIR)]):
            return False
        print("Repository cloned successfully!")

    return True


def convert_imports(content: str) -> str:
    """Convert absolute imports to relative imports."""
    # Pattern to match reflex_ui imports
    patterns = [
        #
        (
            r"from reflex_ui\.components\.icons\.others import",
            "from ...icons.others import",
        ),
        # from reflex_ui.components.icons.hugeicon
        (
            r"from reflex_ui\.components\.icons\.hugeicon import",
            "from ...icons.hugeicon import",
        ),
        # from from reflex_ui.components.component ...
        # (r'from reflex_ui\.components\.component import', 'from .component import'),
        # from reflex_ui.components.base_ui import ...
        (r"from reflex_ui\.components\.base_ui import", "from ..base_ui import"),
        # from reflex_ui.components.component import ...
        (r"from reflex_ui\.components\.component import", "from ..component import"),
        # from reflex_ui.utils.twmerge import ...
        (r"from reflex_ui\.utils\.twmerge import", "from ...utils.twmerge import"),
        # Any other reflex_ui.components imports (catch-all)
        (r"from reflex_ui\.components\.([a-zA-Z_]+) import", r"from .\1 import"),
    ]

    modified_content = content
    for pattern, replacement in patterns:
        modified_content = re.sub(pattern, replacement, modified_content)

    return modified_content


def copy_file(source: Path, dest: Path, convert_imports_flag: bool = True) -> None:
    """Copy a file and optionally convert its imports."""
    # Read source file
    with open(source, "r", encoding="utf-8") as f:
        content = f.read()

    # Convert imports if requested
    if convert_imports_flag:
        content = convert_imports(content)

    # Ensure destination directory exists
    dest.parent.mkdir(parents=True, exist_ok=True)

    # Write to destination
    with open(dest, "w", encoding="utf-8") as f:
        f.write(content)

    print(f"  ✓ Copied: {source.name}")


def should_skip_file(filename: str) -> bool:
    """Check if a file should be skipped."""
    skip_patterns = ["__init__.py", "__pycache__", ".pyc", ".pyo"]
    return any(pattern in filename for pattern in skip_patterns)


def sync_components() -> None:
    """Main function to sync components from reflex-ui to local library."""
    print("=" * 60)
    print("Reflex UI Component Sync")
    print("=" * 60)

    # Step 1: Clone or update the repository
    if not clone_or_update_repo():
        print("Failed to clone/update repository. Exiting.")
        return

    print("\n" + "=" * 60)
    print("Copying files...")
    print("=" * 60)

    # Step 2: Create directory structure
    components_dest = LOCAL_UI_PATH / "components"
    utils_dest = LOCAL_UI_PATH / "utils"
    base_dest = LOCAL_UI_PATH / "components" / "base"

    # Step 3: Copy utils/twmerge.py
    print("\n[1/3] Copying utils...")
    source_twmerge = CACHE_DIR / SOURCE_UTILS
    dest_twmerge = utils_dest / "twmerge.py"
    if source_twmerge.exists():
        copy_file(source_twmerge, dest_twmerge)
    else:
        print(f"  ⚠ Warning: {SOURCE_UTILS} not found")

    # Step 4: Copy base component files
    print("\n[2/3] Copying base component files...")
    source_components = CACHE_DIR / SOURCE_COMPONENTS_DIR
    for base_file in SOURCE_BASE_FILES:
        source_file = source_components / base_file
        dest_file = components_dest / base_file
        if source_file.exists():
            copy_file(source_file, dest_file)
        else:
            print(f"  ⚠ Warning: {base_file} not found")

    # Step 5: Copy all component files from base/
    print("\n[3/3] Copying component files from base/...")
    source_base = CACHE_DIR / SOURCE_BASE_COMPONENTS

    if source_base.exists() and source_base.is_dir():
        component_files = [
            f
            for f in source_base.iterdir()
            if f.is_file() and f.suffix == ".py" and not should_skip_file(f.name)
        ]

        for component_file in component_files:
            dest_file = base_dest / component_file.name
            copy_file(component_file, dest_file)

        print(f"\nTotal components copied: {len(component_files)}")
    else:
        print(f"  ⚠ Warning: {SOURCE_BASE_COMPONENTS} directory not found")

    # Step 6: Create __init__.py files if they don't exist
    print("\n" + "=" * 60)
    print("Creating __init__.py files...")
    print("=" * 60)

    init_dirs = [LOCAL_UI_PATH, utils_dest, components_dest, base_dest]
    for dir_path in init_dirs:
        init_file = dir_path / "__init__.py"
        if not init_file.exists():
            init_file.parent.mkdir(parents=True, exist_ok=True)
            init_file.touch()
            print(f"  ✓ Created: {init_file.relative_to(LOCAL_UI_PATH.parent)}")

    print("\n" + "=" * 60)
    print("✨ Sync completed successfully!")
    print("=" * 60)
    print(f"\nComponents synced to: {LOCAL_UI_PATH}")


if __name__ == "__main__":
    sync_components()



import reflex as rx
from src.docs.library.base_ui.components.base.input_group import (
    input_with_addons,
    textarea_with_footer,
)


def input_price():
    return rx.el.div(
        input_with_addons(
            placeholder="0.00",
            prefix="$",
            suffix="USD",
        ),
        class_name="w-full max-w-sm mx-auto py-6",
    )


def input_url():
    return rx.el.div(
        input_with_addons(
            placeholder="example.com",
            prefix="https://",
            suffix=".com",
        ),
        class_name="w-full max-w-sm mx-auto py-6",
    )


def input_email():
    return rx.el.div(
        input_with_addons(
            placeholder="Enter your username",
            suffix="@company.com",
        ),
        class_name="w-full max-w-sm mx-auto py-6",
    )


def input_textarea():
    return rx.el.div(
        textarea_with_footer(
            placeholder="Enter your message",
            footer_text="120 characters left",
        ),
        class_name="w-full max-w-sm mx-auto py-6",
    )



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
    get_cartesian_grid,
    get_x_axis,
)


def barchart_v6():
    data = [
        {"month": "Jan", "desktop": 186},
        {"month": "Feb", "desktop": 340},
        {"month": "Mar", "desktop": 237, "active": True},
        {"month": "Apr", "desktop": 73},
        {"month": "May", "desktop": 209},
        {"month": "Jun", "desktop": 214},
    ]

    modified_data = [
        {
            **item,
            "stroke": ("var(--chart-3)" if item.get("active", False) else "none"),
        }
        for item in data
    ]

    return rx.box(
        info(
            "Bar Chart - Active",
            "3",
            "Showing total visitors for the last 6 months",
            "start",
        ),
        rx.recharts.bar_chart(
            get_cartesian_grid(),
            get_tooltip(),
            rx.recharts.bar(
                data_key="desktop",
                fill="var(--chart-1)",
                stack_id="a",
                radius=6,
                stroke="stroke",
                stroke_width=3,
            ),
            rx.recharts.y_axis(type_="number", hide=True),
            get_x_axis("month"),
            data=modified_data,
            width="100%",
            height=250,
            margin={"top": 25},
            bar_size=25,
        ),
        info("Trending up by 5.2% this month", "2", "January - June 2024", "start"),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



"""Custom Textarea component."""

from reflex.components.component import Component
from reflex.components.el import Textarea as TextareaComponent

from ..component import CoreComponent


class ClassNames:
    """Class names for textarea components."""

    ROOT = (
        "placeholder:text-[var(--muted-foreground)] "
        "selection:bg-[var(--primary)] selection:text-[var(--primary-foreground)] "
        "dark:bg-[var(--input)]/30 border-[var(--input)] "
        "min-h-20 w-full rounded-md border bg-transparent px-3 py-2 text-base shadow-xs "
        "transition-[color,box-shadow] outline-none resize-none "
        "disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 "
        "md:text-sm "
        "focus-visible:border-[var(--ring)] focus-visible:ring-[var(--ring)]/50 focus-visible:ring-[3px] "
        "aria-invalid:ring-[var(--destructive)]/20 dark:aria-invalid:ring-[var(--destructive)]/40 "
        "aria-invalid:border-[var(--destructive)]"
    )


class Textarea(TextareaComponent, CoreComponent):
    """Root component for Textarea."""

    @classmethod
    def create(cls, *children, **props) -> Component:
        """Create the textarea component."""
        props.setdefault(
            "custom_attrs",
            {
                "autoComplete": "off",
                "autoCapitalize": "none",
                "autoCorrect": "off",
                "spellCheck": "false",
            },
        )
        props["data-slot"] = "textarea"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


textarea = Textarea.create



import reflex as rx


# Used in --show_code(project_setup_init_example)--
def project_setup_init_example():
    return rx.markdown("```bash\nreflex init --name app\n```")


# Used in --show_code(project_setup_run_example)--
def project_setup_run_example():
    return rx.markdown("```bash\nreflex run\n```")


# Used in --show_code(dashboard_layout_example)--
def dashboard_layout_example():
    # Assuming app.layout.sidebar and app.layout.content_header are defined elsewhere
    # For demonstration, we'll use placeholders
    def sidebar():
        return rx.box("Sidebar")

    def content_header():
        return rx.box("Content Header")

    return rx.box(
        sidebar(),
        rx.scroll_area(
            content_header(),
            class_name=(
                "flex flex-col w-full gap-y-2 align-start z-[10] pt-12 "
                "[&_.rt-ScrollAreaScrollbar]:mt-[4rem] "
                "[&_.rt-ScrollAreaScrollbar]:mb-[1rem]"
            ),
            height=["100%" if i == 0 else "100vh" for i in range(6)],
        ),
        class_name="w-[100%] h-[100vh] gap-x-0 flex flex-row",
    )


# Used in --show_code(app_py_example)--
def app_py_example():
    return rx.markdown(
        r"""```
# app/app.py

import reflex as rx
from app.layout.layout import dashboard_layout

def index() -> rx.Component:
    return dashboard_layout()

app = rx.App()
app.add_page(index)
```"""
    )


# Used in --show_code(sidebar_example)--
def sidebar_example():
    # Assuming sidebar_header is defined elsewhere
    def sidebar_header():
        return rx.box("Sidebar Header")

    return rx.scroll_area(
        sidebar_header(),
        rx.box(
            # Sidebar content (e.g., nav links) goes here
            class_name="flex flex-col w-full h-full pt-12 px-2",
        ),
        class_name=(
            "flex flex-col max-w-[300px] w-full h-[100vh] gap-y-2 align-start "
            "sticky top-0 left-0 z-[10] "
            "[&_.rt-ScrollAreaScrollbar]:mr-[0.1875rem] "
            "[&_.rt-ScrollAreaScrollbar]:mt-[4rem] "
            "[&_.rt-ScrollAreaScrollbar]:mb-[1rem]"
        ),
    )


# Used in --show_code(sidebar_header_example)--
def sidebar_header_example():
    return rx.box(
        # You can add a logo, app title, or user info here
        class_name="w-full h-12 p-2 absolute top-0 left-0 z-[99]",
    )


# Used in --show_code(content_header_example)--
def content_header_example():
    return rx.box(
        # You can add breadcrumbs, titles, or action buttons here
        class_name="w-full h-12 p-2 absolute top-0 left-0 z-[99]",
    )


# Used in --show_code(main_content_section_example)--
def main_content_section_example():
    # Assuming content_header, my_chart_component, my_table_component are defined elsewhere
    def content_header():
        return rx.box("Content Header")

    def my_chart_component():
        return rx.box("My Chart Component")

    def my_table_component():
        return rx.box("My Table Component")

    return rx.scroll_area(
        content_header(),
        my_chart_component(),
        my_table_component(),
        # ...
    )



"""Custom collapsible component."""

from reflex.components.component import Component, ComponentNamespace
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent


class ClassNames:
    """Class names for collapsible components."""

    ROOT = "flex flex-col justify-center text-secondary-12"
    TRIGGER = "group flex items-center gap-2"
    PANEL = "flex h-[var(--collapsible-panel-height)] flex-col justify-end overflow-hidden text-sm transition-all ease-out data-[ending-style]:h-0 data-[starting-style]:h-0"


class CollapsibleBaseComponent(BaseUIComponent):
    """Base component for collapsible components."""

    library = f"{PACKAGE_NAME}/collapsible"

    @property
    def import_var(self):
        """Return the import variable for the collapsible component."""
        return ImportVar(tag="Collapsible", package_path="", install=False)


class CollapsibleRoot(CollapsibleBaseComponent):
    """Groups all parts of the collapsible. Renders a <div> element."""

    tag = "Collapsible.Root"

    # Whether the collapsible panel is initially open. To render a controlled collapsible, use the `open` prop instead. Defaults to False.
    default_open: Var[bool]

    # Whether the collapsible panel is currently open. To render an uncontrolled collapsible, use the `default_open` prop instead.
    open: Var[bool]

    # Event handler called when the panel is opened or closed.
    on_open_change: EventHandler[passthrough_event_spec(bool)]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the collapsible root component."""
        props["data-slot"] = "collapsible"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


class CollapsibleTrigger(CollapsibleBaseComponent):
    """A button that opens and closes the collapsible panel. Renders a <button> element."""

    tag = "Collapsible.Trigger"

    # Whether the component renders a native `<button>` element when replacing it via the `render` prop. Set to `false` if the rendered element is not a button (e.g. `<div>`). Defaults to True.
    native_button: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the collapsible trigger component."""
        props["data-slot"] = "collapsible-trigger"
        cls.set_class_name(ClassNames.TRIGGER, props)
        return super().create(*children, **props)


class CollapsiblePanel(CollapsibleBaseComponent):
    """A panel with the collapsible contents. Renders a <div> element."""

    tag = "Collapsible.Panel"

    # Allows the browser's built-in page search to find and expand the panel contents. Overrides the `keep_mounted` prop and uses `hidden="until-found"` to hide the element without removing it from the DOM. Defaults to False.
    hidden_until_found: Var[bool]

    # Whether to keep the element in the DOM while the panel is hidden. This prop is ignored when `hidden_until_found` is used. Defaults to False.
    keep_mounted: Var[bool]

    # Allows you to replace the component's HTML element with a different tag, or compose it with another component. Accepts a `ReactElement` or a function that returns the element to render.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the collapsible panel component."""
        props["data-slot"] = "collapsible-panel"
        cls.set_class_name(ClassNames.PANEL, props)
        return super().create(*children, **props)


class HighLevelCollapsible(CollapsibleRoot):
    """High level collapsible component."""

    # The trigger component.
    trigger: Var[Component | None]

    # The content component.
    content: Var[str | Component | None]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the collapsible component."""
        trigger = props.pop("trigger", None)
        content = props.pop("content", None)

        return CollapsibleRoot.create(
            CollapsibleTrigger.create(render_=trigger) if trigger else None,
            CollapsiblePanel.create(
                content,
                *children,
            ),
            **props,
        )

    def _exclude_props(self) -> list[str]:
        return [
            *super()._exclude_props(),
            "trigger",
            "content",
        ]


class Collapsible(ComponentNamespace):
    """Namespace for Collapsible components."""

    root = staticmethod(CollapsibleRoot.create)
    trigger = staticmethod(CollapsibleTrigger.create)
    panel = staticmethod(CollapsiblePanel.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelCollapsible.create)


collapsible = Collapsible()



import random
import string
import reflex as rx

from reflex.experimental import ClientStateVar

# --- Markdown Styles ---
PARAGRAPH_CLASS = "text-sm leading-6 pb-4"
HEADING_1_CLASS = "text-2xl py-1"
HEADING_2_CLASS = "text-xl py-1"
LIST_ITEM_CLASS = "text-sm text-slate-11"
LINK_CLASS = "text-accent-8"
CODE_BLOCK_CLASS = "!rounded-xl !bg-transparent"


# --- Helper functions to generate ClientStateVar names ---
def generate_component_id():
    """Generate a unique component ID."""
    return "".join(random.choices(string.ascii_letters + string.digits, k=10))


# --- Helper error functions during parsing ---
def render_parse_error(msg: str):
    return rx.el.p(msg, class_name="text-sm text-red-500")


# --- Helper functions ---
def render_heading(level: int, text: str) -> rx.Component:
    return rx.heading(
        text, class_name=HEADING_1_CLASS if level == 1 else HEADING_2_CLASS, id=text
    )


def render_paragraph(text: str) -> rx.Component:
    return rx.text(text, class_name=PARAGRAPH_CLASS)


def render_list_item(text: str) -> rx.Component:
    return rx.list_item(rx.text(text, class_name=LIST_ITEM_CLASS))


def render_link(text: str, **props) -> rx.Component:
    return rx.link(text, class_name=LINK_CLASS, **props)


def render_codeblock(
    content: str,
    lang: str = "python",
    copy_button: bool = False,
    line_num: bool = False,
    **props,
) -> rx.Component:
    # Use the following to make line numbers sticky when horizontally scrolling...
    # style={
    #     ".linenumber.react-syntax-highlighter-line-number": {
    #         "position": "sticky",
    #         "left": "0",
    #         "background-color": "var(--input)",
    #         "zIndex": 1,
    #         "textAlign": "right",
    #         "paddingRight": "8px",
    #         "color": "#999",
    #         "userSelect": "none",
    #     }
    # },

    if copy_button:
        _id = generate_component_id()
        is_copied = ClientStateVar.create(var_name=f"is_copied_{_id}", default=False)

    return rx.el.div(
        rx.code_block(
            content,
            font_size="13px",
            language=lang,
            show_line_numbers=line_num,
            code_tag_props={
                "pre": "transparent",
                "background": "transparent",
            },
            custom_attrs={
                "background": "transparent !important",
                "pre": {"background": "transparent !important"},
                "code": {"background": "transparent !important"},
            },
            background="transparent !important",
            class_name=CODE_BLOCK_CLASS,
        ),
        (
            rx.el.button(
                rx.cond(
                    is_copied.value,
                    rx.icon("check", size=14),
                    rx.icon("clipboard", size=14),
                ),
                class_name="cursor-pointer flex items-center justify-center absolute top-[15px] right-[15px]",
                on_click=[
                    rx.call_function(is_copied.set_value(True)),
                    rx.set_clipboard(content),
                ],
                on_mouse_down=rx.call_function(is_copied.set_value(False)).debounce(
                    1500
                ),
            )
            if copy_button
            else rx.el.div(class_name="hidden")
        ),
        class_name="w-full rounded-[0.625rem] relative bg-input/18 outline outline-input mb-4",
    )


# --- Final Component Map ---
markdown_component_map = {
    "h1": lambda text: render_heading(1, text),
    "h2": lambda text: render_heading(2, text),
    "p": render_paragraph,
    "li": render_list_item,
    "codeblock": render_codeblock,
    "a": render_link,
}



import reflex as rx

from ...base_ui.components.base.badge import badge


def badge_demo():
    return rx.box(
        rx.box(
            badge("Badge"),
            badge("Secondary", variant="secondary"),
            badge("Destructive", variant="destructive"),
            badge("Outline", variant="outline"),
            class_name="flex w-full flex-wrap gap-2",
        ),
        rx.box(
            badge(
                rx.icon(tag="badge-check"),
                "Verified",
                variant="secondary",
                class_name="bg-blue-500 text-white dark:bg-blue-600",
            ),
            badge(
                "8",
                class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
            ),
            badge(
                "99",
                variant="destructive",
                class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
            ),
            badge(
                "20+",
                variant="outline",
                class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
            ),
            class_name="flex w-full flex-wrap gap-2",
        ),
        class_name="flex flex-col items-center gap-2 p-8",
    )


def badge_with_icons():
    return rx.box(
        badge(
            rx.icon(tag="check"),
            "Success",
            variant="secondary",
            class_name="bg-green-500 text-white dark:bg-green-600",
        ),
        badge(
            rx.icon(tag="x"),
            "Error",
            variant="destructive",
        ),
        badge(
            rx.icon(tag="triangle-alert"),
            "Warning",
            variant="secondary",
            class_name="bg-yellow-500 text-white dark:bg-yellow-600",
        ),
        badge(
            rx.icon(tag="info"),
            "Info",
            variant="secondary",
            class_name="bg-blue-500 text-white dark:bg-blue-600",
        ),
        class_name="flex flex-wrap gap-2 p-8",
    )


def badge_status_examples():
    return rx.box(
        badge("New", variant="default"),
        badge("Popular", variant="secondary"),
        badge("Sale", variant="destructive"),
        badge("Draft", variant="outline"),
        badge(
            rx.icon(tag="star"),
            "Featured",
            class_name="bg-yellow-500 text-white dark:bg-yellow-600",
        ),
        class_name="flex flex-wrap gap-2 p-8",
    )


def badge_notification_count():
    return rx.box(
        badge(
            "1",
            class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
        ),
        badge(
            "5",
            variant="destructive",
            class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
        ),
        badge(
            "10",
            variant="secondary",
            class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
        ),
        badge(
            "99+",
            variant="destructive",
            class_name="h-5 min-w-5 rounded-full px-1 font-mono tabular-nums",
        ),
        class_name="flex items-center gap-2 p-8",
    )



import reflex as rx
import src.routes as routes

from typing import List
from dataclasses import dataclass

from src.hooks import selected_page


@dataclass
class SidebarSection:
    """Configuration for a sidebar section."""

    title: str
    description: str
    routes: list[dict]


SIDEBAR_SECTIONS = [
    SidebarSection(
        title="Getting Started",
        description="Quickly set up and get started with the basics of buridan/ui.",
        routes=routes.GET_STARTED_URLS,
    ),
    SidebarSection(
        title="Wrapped React Components",
        description="Explore React components elegantly wrapped for Reflex",
        routes=routes.WRAPPED_COMPONENTS_URLS,
    ),
    SidebarSection(
        title="JavaScript Integrations",
        description="Learn how to extend Reflex apps with native JavaScript libraries.",
        routes=routes.JS_INTEGRATIONS_URLS,
    ),
    SidebarSection(
        title="Charts",
        description="A collection of chart components to help visualize data, build dashboards, and more.",
        routes=routes.CHARTS_URLS,
    ),
    SidebarSection(
        title="Components",
        description="Core components to help you build beautiful and visually consistent applications.",
        routes=routes.BASE_UI_COMPONENTS,
    ),
    # SidebarSection(
    #     title="Components",
    #     description="Core components to help you build beautiful and visually consistent applications.",
    #     routes=routes.COMPONENTS_URLS,
    # ),
]


def create_section_description(text: str):
    """Create a consistent section description."""
    return rx.el.label(
        text,
        class_name="text-sm font-medium pt-1 pb-2 text-muted-foreground",
    )


def create_menu_item(data: dict):
    """Create a single menu item."""
    return rx.el.div(
        rx.el.a(
            rx.el.label(
                data["title"],
                color=rx.color("slate", 12),
                class_name="cursor-pointer text-sm "
                + rx.cond(
                    selected_page.value == data["url"], "font-bold", "font-regular"
                ).to(str),
            ),
            to=f"/{data['url']}",
            text_decoration="none",
        ),
        class_name="w-full",
        id=data["url"],
    )


def create_sidebar_menu_items(routes: List[dict]):
    """Create menu items from routes."""
    return rx.box(
        *[create_menu_item(route) for route in routes],
        class_name="w-full flex flex-col gap-y-0",
    )


def create_section_content(section: SidebarSection):
    """Create content for a sidebar section."""
    return rx.el.div(
        # create_section_description(section.description),
        rx.el.div(
            create_sidebar_menu_items(section.routes),
            class_name="flex flex-row h-full w-full gap-x-2",
        ),
        class_name="flex flex-col p-0 m-0",
    )


def sidebar_section(section: SidebarSection):
    """Create a complete sidebar section with title and content."""
    return rx.el.div(
        rx.el.div(
            rx.el.div(
                rx.el.label(
                    section.title,
                    color=rx.color("slate", 12),
                    class_name="text-sm font-bold",
                ),
                class_name="flex flex-row items-center gap-x-2",
            ),
            class_name="w-full flex flex-row justify-between align-center items-center",
        ),
        create_section_content(section),
        class_name="flex flex-col w-full gap-y-2 p-4",
    )


def sidebar(in_drawer=False):
    """Main sidebar component."""
    content = rx.el.div(
        *[sidebar_section(section) for section in SIDEBAR_SECTIONS],
        class_name="flex flex-col max-w-[18rem] w-full h-full",
    )

    drawer_classes = "flex flex-col w-full h-full"
    default_classes = (
        "hidden xl:flex max-w-[18rem] w-full sticky top-12 max-h-[100vh] z-[10] pb-5"
    )

    return rx.el.div(
        rx.scroll_area(
            content,
            class_name="flex flex-col items-center gap-y-4 [&_.rt-ScrollAreaScrollbar]:mt-[2rem] [&_.rt-ScrollAreaScrollbar]:mb-[2rem]",
        ),
        class_name=drawer_classes if in_drawer else default_classes,
    )



import reflex as rx

from src.docs.library.base_ui.components.base.button import button
from src.docs.library.wrapped_components.simple_icon.simple_icon import simple_icon


def site_theme() -> rx.Component:
    return button(
        rx.color_mode.icon(
            light_component=rx.image(
                "/svg/theme/theme_light.svg",
                class_name="size-4 !shrink-0 text-neutral-900",
            ),
            dark_component=rx.image(
                "/svg/theme/theme_dark.svg",
                class_name="size-4 !shrink-0 text-white invert brightness-0",
            ),
        ),
        on_click=rx.toggle_color_mode,
        variant="ghost",
        size="sm",
        class_name="cursor-pointer",
    )


def site_github() -> rx.Component:
    return rx.el.a(
        button(
            simple_icon("SiGithub"),
            rx.el.p("7", class_name="text-xs font-semibold text-muted-foreground"),
            class_name="cursor-pointer flex flex-row items-center gap-x-2",
            variant="ghost",
            size="sm",
        ),
        href="https://github.com/sapphireUI/SapphireUI",
        class_name="no-underline",
    )


def site_reflex_build():
    return rx.el.a(
        button(
            rx.el.image(
                rx.color_mode_cond(
                    "/svg/reflex/reflex_light.svg",
                    "/svg/reflex/reflex_dark.svg",
                ),
            ),
            "Build",
            variant="ghost",
        ),
        href="https://build.reflex.dev/",
    )



import reflex as rx
from ...base_ui.components.base.accordion import accordion


def accordion_example():
    """Accordion with space exploration data - only one section open at a time."""

    items1 = [
        "01. Genesis launched a new era of exploration.",
        "02. Explorer uncovered new planets beyond our reach.",
        "03. Voyager 1 ventured into interstellar space.",
        "04. Apollo landed humans on the Moon.",
    ]

    items2 = [
        "05. Curiosity sent back valuable data from Mars.",
        "06. The Hubble Telescope captured distant galaxies.",
        "07. James Webb will explore the universe's origins.",
        "08. The ISS orbits Earth, conducting critical experiments.",
    ]

    items3 = [
        "09. Saturn's rings have fascinated scientists for years.",
        "10. The Mars Rover is studying the planet's surface.",
        "11. NASA's Artemis program aims to return humans to the Moon.",
        "12. Solar missions help us understand space weather.",
    ]

    return accordion.root(
        accordion.item(
            accordion.header(
                accordion.trigger(
                    "Models",
                    # icon("PlusSignIcon", class_name="size-4 shrink-0 transition-all ease-out group-data-[panel-open]:scale-110 group-data-[panel-open]:rotate-45"),
                ),
            ),
            accordion.panel(
                rx.box(
                    *[rx.text(item, class_name="mb-2") for item in items1],
                    class_name="py-2 px-4",
                ),
            ),
            value="section-1",
        ),
        accordion.item(
            accordion.header(
                accordion.trigger(
                    "Spacecraft",
                    # icon("PlusSignIcon", class_name="size-4 shrink-0 transition-all ease-out group-data-[panel-open]:scale-110 group-data-[panel-open]:rotate-45"),
                ),
            ),
            accordion.panel(
                rx.box(
                    *[rx.text(item, class_name="mb-2") for item in items2],
                    class_name="py-2 px-4",
                ),
            ),
            value="section-2",
        ),
        accordion.item(
            accordion.header(
                accordion.trigger(
                    "Space Discoveries",
                    # icon("PlusSignIcon", class_name="size-4 shrink-0 transition-all ease-out group-data-[panel-open]:scale-110 group-data-[panel-open]:rotate-45"),
                ),
            ),
            accordion.panel(
                rx.box(
                    *[rx.text(item, class_name="mb-2") for item in items3],
                    class_name="py-2 px-4",
                ),
            ),
            value="section-3",
        ),
        class_name="w-full max-w-md mx-auto",
        open_multiple=False,
        default_value=[],
    )



import reflex as rx
from src.docs.library.charts.util import (
    get_tooltip,
    get_x_axis,
)


def linechart_v8():
    data = [
        {"month": "Jan", "desktop": 186, "mobile": 80},
        {"month": "Feb", "desktop": 305, "mobile": 200},
        {"month": "Mar", "desktop": 237, "mobile": 120},
        {"month": "Apr", "desktop": 73, "mobile": 190},
        {"month": "May", "desktop": 209, "mobile": 130},
        {"month": "Jun", "desktop": 214, "mobile": 140},
    ]
    return rx.box(
        rx.hstack(
            rx.foreach(
                [["Desktop", "var(--chart-1)"], ["Mobile", "var(--chart-2)"]],
                lambda key: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=key[1]),
                    rx.text(
                        key[0],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full flex justify-center gap-8",
        ),
        rx.recharts.line_chart(
            get_tooltip(),
            rx.recharts.line(
                data_key="desktop",
                stroke="var(--chart-1)",
                type_="linear",
                dot=False,
                stroke_width=2,
            ),
            rx.recharts.line(
                data_key="mobile",
                stroke="var(--chart-2)",
                type_="linear",
                dot=False,
                stroke_width=2,
            ),
            get_x_axis("month"),
            data=data,
            width="100%",
            height=250,
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



"""Custom scroll area component."""

from typing import Literal

from reflex.components.component import Component, ComponentNamespace
from reflex.components.core.cond import cond
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from ..base_ui import PACKAGE_NAME, BaseUIComponent
from ...utils.twmerge import cn

LiteralOrientation = Literal["horizontal", "vertical"]


class ClassNames:
    """Class names for scroll area components."""

    ROOT = "h-full outline-none focus:outline-none"
    VIEWPORT = "h-full overscroll-contain"
    CONTENT = ""
    SCROLLBAR_BASE = "flex touch-none p-0.5 opacity-0 transition-[colors,opacity] delay-200 select-none data-hovering:opacity-100 data-hovering:delay-0 data-hovering:duration-100 data-scrolling:opacity-100 data-scrolling:delay-0 data-scrolling:duration-100"
    SCROLLBAR_VERTICAL = "w-2"
    SCROLLBAR_HORIZONTAL = "h-2"
    THUMB = "w-full rounded-full bg-secondary"
    CORNER = "bg-secondary"


class ScrollAreaBaseComponent(BaseUIComponent):
    """Base component for scroll area components."""

    library = f"{PACKAGE_NAME}/scroll-area"

    @property
    def import_var(self):
        """Return the import variable for the scroll area component."""
        return ImportVar(tag="ScrollArea", package_path="", install=False)


class ScrollAreaRoot(ScrollAreaBaseComponent):
    """The root of the scroll area."""

    tag = "ScrollArea.Root"

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area root component."""
        props["data-slot"] = "scroll-area"
        cls.set_class_name(ClassNames.ROOT, props)
        return super().create(*children, **props)


class ScrollAreaViewport(ScrollAreaBaseComponent):
    """The viewport of the scroll area."""

    tag = "ScrollArea.Viewport"

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area viewport component."""
        props["data-slot"] = "scroll-area-viewport"
        cls.set_class_name(ClassNames.VIEWPORT, props)
        return super().create(*children, **props)


class ScrollAreaContent(ScrollAreaBaseComponent):
    """A container for the content of the scroll area."""

    tag = "ScrollArea.Content"

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area content component."""
        props["data-slot"] = "scroll-area-content"
        cls.set_class_name(ClassNames.CONTENT, props)
        return super().create(*children, **props)


class ScrollAreaScrollbar(ScrollAreaBaseComponent):
    """The scrollbar of the scroll area."""

    tag = "ScrollArea.Scrollbar"

    # Orientation of the scrollbar
    orientation: Var[LiteralOrientation] = Var.create("vertical")

    # Whether to keep the HTML element in the DOM when the viewport isn't scrollable
    keep_mounted: Var[bool] = Var.create(False)

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area scrollbar component."""
        props["data-slot"] = "scroll-area-scrollbar"
        orientation = props.get("orientation", "vertical")

        scrollbar_classes = cn(
            ClassNames.SCROLLBAR_BASE,
            cond(
                orientation == "vertical",
                ClassNames.SCROLLBAR_VERTICAL,
                ClassNames.SCROLLBAR_HORIZONTAL,
            ),
        )

        cls.set_class_name(scrollbar_classes, props)
        return super().create(*children, **props)


class ScrollAreaThumb(ScrollAreaBaseComponent):
    """The thumb of the scrollbar."""

    tag = "ScrollArea.Thumb"

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area thumb component."""
        props["data-slot"] = "scroll-area-thumb"
        cls.set_class_name(ClassNames.THUMB, props)
        return super().create(*children, **props)


class ScrollAreaCorner(ScrollAreaBaseComponent):
    """A small rectangular area that appears at the intersection of horizontal and vertical scrollbars."""

    tag = "ScrollArea.Corner"

    # Render prop
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the scroll area corner component."""
        props["data-slot"] = "scroll-area-corner"
        cls.set_class_name(ClassNames.CORNER, props)
        return super().create(*children, **props)


class HighLevelScrollArea(ScrollAreaRoot):
    """High level wrapper for the Scroll Area component."""

    # Orientation of the scroll area
    orientation: Var[LiteralOrientation] = Var.create("vertical")

    # Whether to keep the HTML element in the DOM when the viewport isn't scrollable
    keep_mounted: Var[bool] = Var.create(False)

    # Props for different component parts
    _scrollbar_props = {"orientation", "keep_mounted"}

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create a high level scroll area component.

        Args:
            *children: The content to be scrollable.
            **props: Additional properties to apply to the scroll area component.

        Returns:
            The scroll area component.
        """
        # Extract props for different parts
        scrollbar_props = {k: props.pop(k) for k in cls._scrollbar_props & props.keys()}

        return ScrollAreaRoot.create(
            ScrollAreaViewport.create(
                ScrollAreaContent.create(
                    *children,
                ),
            ),
            ScrollAreaScrollbar.create(
                ScrollAreaThumb.create(),
                **scrollbar_props,
            ),
            **props,
        )


class ScrollArea(ComponentNamespace):
    """Namespace for Scroll Area components."""

    root = staticmethod(ScrollAreaRoot.create)
    viewport = staticmethod(ScrollAreaViewport.create)
    content = staticmethod(ScrollAreaContent.create)
    scrollbar = staticmethod(ScrollAreaScrollbar.create)
    thumb = staticmethod(ScrollAreaThumb.create)
    corner = staticmethod(ScrollAreaCorner.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelScrollArea.create)


scroll_area = ScrollArea()



import reflex as rx
from src.docs.library.base_ui.components.base.button import button
import src.hooks as hooks

THEME_OPTIONS = [
    ("Hematite", "gray","स्लेटी" ),
    ("Feyrouz", "blue","नीला" ),
    ("Yaqout", "red","लाल" ),
    ("Zumurrud", "green","हरा" ),
    ("Kahraman", "amber","अंबर" ),
    ("Amethyst", "purple","बैंगनी" ),
]


def theme_buttons():
    return rx.el.div(
        rx.el.div(
            *[
                rx.el.div(
                    button(
                        rx.el.div(
                            rx.el.div(
                                class_name=f"w-3 h-3 rounded-sm bg-{theme_class}-500"
                            ),
                            rx.el.p(name, class_name="text-sm"),
                            class_name="flex flex-row items-center gap-x-2",
                        ),
                        variant="ghost",
                        size="sm",
                        on_click=hooks.current_theme.set_value(theme_class),
                    ),
                    class_name="rounded-lg "
                    + rx.cond(
                        hooks.current_theme.value == theme_class,
                        "border border-primary",
                        "",
                    ).to(str),
                )
                for name,theme_class,_ in THEME_OPTIONS
            ],
            class_name=(
                "w-full flex flex-row flex-wrap gap-4 items-center "
                "justify-center md:justify-start px-8 pt-10 "
                + rx.color_mode_cond(
                    f"theme-{hooks.current_theme.value}",
                    f"theme-{hooks.current_theme.value}-dark",
                ).to(str)
            ),
        )
    )



import reflex as rx
from src.docs.library.charts.util import get_tooltip, get_cartesian_grid


def areachart_v8():
    data = [
        {"month": "Jan", "desktop": 186, "mobile": 80},
        {"month": "Feb", "desktop": 305, "mobile": 200},
        {"month": "Mar", "desktop": 237, "mobile": 120},
        {"month": "Apr", "desktop": 73, "mobile": 190},
        {"month": "May", "desktop": 209, "mobile": 130},
        {"month": "Jun", "desktop": 214, "mobile": 140},
    ]

    series = [("desktop", "Desktop", "--chart-1"), ("mobile", "Mobile", "--chart-2")]

    def create_gradient(var_name):
        return rx.el.svg.defs(
            rx.el.svg.linear_gradient(
                rx.el.svg.stop(
                    stop_color=f"var({var_name})", offset="5%", stop_opacity=0.8
                ),
                rx.el.svg.stop(
                    stop_color=f"var({var_name})", offset="95%", stop_opacity=0.1
                ),
                x1=0,
                x2=0,
                y1=0,
                y2=1,
                id=var_name.strip("-"),
            )
        )

    return rx.box(
        rx.hstack(
            rx.foreach(
                series,
                lambda s: rx.hstack(
                    rx.box(class_name="w-3 h-3 rounded-sm", bg=f"var({s[2]})"),
                    rx.text(
                        s[1],
                        class_name="text-sm font-semibold",
                        color=rx.color("slate", 11),
                    ),
                    align="center",
                    spacing="2",
                ),
            ),
            class_name="py-4 px-4 flex w-full justify-center gap-8",
        ),
        rx.recharts.area_chart(
            *(create_gradient(s[2]) for s in series),
            get_tooltip(),
            get_cartesian_grid(),
            *(
                rx.recharts.area(
                    data_key=s[0],
                    fill=f"url(#{s[2].strip('-')})",
                    stroke=f"var({s[2]})",
                    stack_id="1",
                )
                for s in series
            ),
            rx.recharts.x_axis(
                data_key="month",
                axis_line=False,
                tick_size=10,
                tick_line=False,
                custom_attrs={"fontSize": "12px"},
                interval="preserveStartEnd",
            ),
            data=data,
            width="100%",
            height=250,
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 [&_.recharts-tooltip-item-separator]:w-full",
    )



from typing import Literal

from reflex.components.core.cond import cond
from reflex.components.el import Button as BaseButton
from reflex.vars.base import Var

from ..component import CoreComponent
from ...icons.others import spinner

LiteralButtonVariant = Literal[
    "primary", "destructive", "outline", "secondary", "ghost", "link", "dark"
]
LiteralButtonSize = Literal[
    "xs", "sm", "md", "lg", "xl", "icon-xs", "icon-sm", "icon-md", "icon-lg", "icon-xl"
]

DEFAULT_CLASS_NAME = (
    "inline-flex items-center justify-center gap-2 whitespace-nowrap "
    "rounded-md text-sm font-medium transition-all "
    "disabled:pointer-events-none disabled:opacity-50 outline-none "
    "[&_svg]:pointer-events-none [&_svg:not([class*='size-'])]:size-4 "
    "[&_svg]:shrink-0 shrink-0"
)

BUTTON_VARIANTS = {
    "variant": {
        "default": "bg-primary text-primary-foreground hover:bg-primary/90",
        "destructive": (
            "bg-[var(--destructive)] text-white hover:bg-[var(--destructive)]/90 "
            "focus-visible:ring-[var(--destructive)]/20 "
            "dark:focus-visible:ring-[var(--destructive)]/40 "
            "dark:bg-[var(--destructive)]/60"
        ),
        "outline": (
            "border border-input bg-background shadow-xs "
            "hover:bg-[var(--accent)] hover:text-[var(--accent-foreground)] "
            "dark:bg-[var(--input)]/30 dark:border-input "
            "dark:hover:bg-[var(--input)]/50"
        ),
        "secondary": ("bg-secondary text-secondary-foreground hover:bg-secondary/80"),
        "ghost": (
            "hover:bg-accent hover:text-accent-foreground "
            "dark:hover:bg-[var(--accent)]/50"
        ),
        "link": "text-primary underline-offset-4 hover:underline",
    },
    "size": {
        "default": "h-9 px-4 py-2 has-[>svg]:px-3",
        "sm": "h-8 rounded-md gap-1.5 px-3 has-[>svg]:px-2.5",
        "lg": "h-10 rounded-md px-6 has-[>svg]:px-4",
        "icon": "size-9",
        "icon-sm": "size-8",
        "icon-lg": "size-10",
    },
}


class Button(BaseButton, CoreComponent):
    """A custom button component."""

    # Button variant. Defaults to "primary".
    variant: Var[LiteralButtonVariant]

    # Button size. Defaults to "md".
    size: Var[LiteralButtonSize]

    # The loading state of the button
    loading: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseButton:
        """Create the button component."""
        variant = props.pop("variant", "default")
        cls.validate_variant(variant)

        size = props.pop("size", "default")
        cls.validate_size(size)

        loading = props.pop("loading", False)
        disabled = props.pop("disabled", False)

        button_classes = f"{DEFAULT_CLASS_NAME} {BUTTON_VARIANTS['variant'][variant]} {BUTTON_VARIANTS['size'][size]}"

        cls.set_class_name(button_classes, props)

        children_list = list(children)

        if isinstance(loading, Var):
            props["disabled"] = cond(loading, True, disabled)
            children_list.insert(0, cond(loading, spinner()))
        else:
            props["disabled"] = True if loading else disabled
            children_list.insert(0, spinner()) if loading else None

        return super().create(*children_list, **props)

    @staticmethod
    def validate_variant(variant: LiteralButtonVariant):
        """Validate the button variant."""
        if variant not in BUTTON_VARIANTS["variant"]:
            available_variants = ", ".join(BUTTON_VARIANTS["variant"].keys())
            message = (
                f"Invalid variant: {variant}. Available variants: {available_variants}"
            )
            raise ValueError(message)

    @staticmethod
    def validate_size(size: LiteralButtonSize):
        """Validate the button size."""
        if size not in BUTTON_VARIANTS["size"]:
            available_sizes = ", ".join(BUTTON_VARIANTS["size"].keys())
            message = f"Invalid size: {size}. Available sizes: {available_sizes}"
            raise ValueError(message)

    def _exclude_props(self) -> list[str]:
        return [
            *super()._exclude_props(),
            "size",
            "variant",
            "loading",
        ]


button = Button.create



import re
import ast
import inspect
import pathlib
import importlib
import reflex as rx

from typing import Dict, Callable, List
from src.docs.constants import DocParserCommands
from src.docs.style import render_parse_error, markdown_component_map
from src.comps.docs.wrapper import (
    demo_and_code_single_file_wrapper,
    cli_and_manual_installation_wrapper,
)


class DocParser:
    def __init__(
        self,
        components_registry: Dict[str, Callable] | None = None,
        dynamic_load_dirs: List[str] | None = None,
    ):
        self.components_registry = components_registry or {}
        if dynamic_load_dirs:
            for directory in dynamic_load_dirs:
                self.components_registry.update(self._dynamic_load(directory))

        self.command_handlers = {
            DocParserCommands.DEMO_AND_CODE_SINGLE_FILE: self._handle_demo_and_code_single_file,
            DocParserCommands.SHOW_CODE_WITH_LANGUAGE: self._handle_show_code_with_language,
            DocParserCommands.DEMO_AND_SINGLE_FUNCTION: self._handle_demo_and_single_function,
            DocParserCommands.FULL_SOURCE_PAGE_OF_COMPONENT: self._handel_full_source_page_of_component,
            DocParserCommands.CLI_AND_MANUAL_INSTALLATION: self._handle_cli_and_manual_installation,
        }

    def parse_and_render(self, content: str) -> List[rx.Component]:
        sections = self._parse_sections(content)
        components = []
        for section in sections:
            if section["type"] == "content":
                components.append(
                    rx.markdown(
                        section["value"],
                        component_map=markdown_component_map,
                        class_name="px-4",
                    )
                )
            elif section["type"] == "command":
                components.append(
                    self._handle_command(section["command"], section["argument"])
                )
        return components

    def _handle_command(self, command: str, argument: str | None) -> rx.Component:
        command_lower = command.lower()
        handler = self.command_handlers.get(command_lower)

        if handler:
            return handler(argument)

        if command_lower in self.components_registry and argument is None:
            component_func = self.components_registry[command_lower]
            return component_func()

        return render_parse_error(msg=f"Unknown component or command: {command}")

    def _dynamic_load(self, directory: str) -> Dict[str, Callable]:
        """Dynamically loads components from a given directory."""
        registry = {}
        root_dir = pathlib.Path(__file__).parent.parent.parent
        search_path = root_dir / directory

        if not search_path.is_dir():
            print(f"Warning: Dynamic load directory not found: {directory}")
            return {}

        for py_file in search_path.rglob("*.py"):
            if py_file.name.startswith("__"):
                continue

            # Create module path for importlib
            relative_py_file = py_file.relative_to(root_dir)
            module_path = ".".join(relative_py_file.with_suffix("").parts)
            try:
                module = importlib.import_module(module_path)
                for name, obj in inspect.getmembers(module):
                    if (
                        inspect.isfunction(obj) or inspect.isclass(obj)
                    ) and obj.__module__ == module.__name__:
                        registry[name.lower()] = obj
            except Exception as e:
                print(f"Error loading components from module {module_path}: {e}")
        return registry

    def _parse_sections(self, content: str) -> List[Dict]:
        delimiter_pattern = r"--([\w_]+)(?:\(([^)]+)\))?--"
        sections = []
        current_pos = 0

        for match in re.finditer(delimiter_pattern, content):
            if match.start() > current_pos:
                text_content = content[current_pos : match.start()].strip()
                if text_content:
                    sections.append({"type": "content", "value": text_content})

            command = match.group(1)
            argument = match.group(2)
            sections.append(
                {"type": "command", "command": command, "argument": argument}
            )
            current_pos = match.end()

        if current_pos < len(content):
            remaining_content = content[current_pos:].strip()
            if remaining_content:
                sections.append({"type": "content", "value": remaining_content})

        return sections

    def _create_code_block_markdown(
        self, code: str, language: str = "python"
    ) -> rx.Component:
        md_code = f"```{language}\n{code}```"

        return rx.markdown(
            md_code,
            component_map=markdown_component_map,
            class_name="px-4",
        )

    def _handle_cli_and_manual_installation(self, argument: str | None):
        if not argument:
            return render_parse_error(
                msg="Missing argument for cli_and_manual_installation"
            )

        try:
            args = ast.literal_eval(argument)
            if not isinstance(args, list) or len(args) != 2:
                return render_parse_error(
                    msg='Invalid argument format for CLI_AND_MANUAL_INSTALLATION. Expected ["ComponentName", "cli command"]'
                )

            component_name, cli_command = args
            component_name_lower = component_name.lower()

            if component_name_lower not in self.components_registry:
                return render_parse_error(msg=f"Component not found: {component_name}")

            func = self.components_registry[component_name_lower]
            file_path = inspect.getfile(func)
            full_source = pathlib.Path(file_path).read_text()

            return cli_and_manual_installation_wrapper(cli_command, full_source)

        except (ValueError, SyntaxError, IndexError) as e:
            return render_parse_error(
                msg=f"Error parsing arguments for CLI_AND_MANUAL_INSTALLATION: {e}"
            )
        except Exception as e:
            return render_parse_error(msg=f"Error loading source: {e}")

    def _handel_full_source_page_of_component(
        self, argument: str | None
    ) -> rx.Component:
        if not argument:
            return render_parse_error(
                msg="Missing argument for full_source_page_of_component"
            )

        arg_lower = argument.lower()
        if arg_lower not in self.components_registry:
            return render_parse_error(msg=f"Component not found: {argument}")

        func = self.components_registry[arg_lower]

        try:
            file_path = inspect.getfile(func)
            full_source = pathlib.Path(file_path).read_text()

            return self._create_code_block_markdown(full_source, "python")

        except Exception as e:
            return render_parse_error(msg=f"Error loading source: {e}")

    def _handle_show_code_with_language(self, argument: str | None) -> rx.Component:
        if not argument:
            return render_parse_error(
                msg="Missing arguments for show_code_with_language"
            )

        try:
            args = ast.literal_eval(argument)

            if not isinstance(args, list) or len(args) == 0:
                return render_parse_error(
                    msg="Invalid argument format. Expected a list. Example: [function_name, code_block_langauge]"
                )

            arg_lower = args[0].lower()
            if arg_lower not in self.components_registry:
                return render_parse_error(
                    msg=f"Missing component for show_code_with_language: {args[0]}"
                )

            return self._create_code_block_markdown(
                inspect.getsource(self.components_registry[arg_lower]), args[1]
            )

        except (ValueError, SyntaxError):
            return render_parse_error(
                msg="Error parsing arguments. Ensure they are in a valid format."
            )

    def _handle_demo_and_code_single_file(self, argument: str | None) -> rx.Component:
        if not argument:
            return render_parse_error(
                msg="Missing arguments for demo_and_code_single_file"
            )

        arg_lower = argument.lower()
        try:
            if not isinstance(arg_lower, str):
                return render_parse_error(
                    msg="Invalid argument format. Expected a string. Example: function_name"
                )

            if arg_lower not in self.components_registry:
                return render_parse_error(
                    msg=f"Missing component for demo_and_code_single_file: {argument}"
                )

            component = self.components_registry[arg_lower]
            module = inspect.getmodule(component)
            source_code = inspect.getsource(module)
            component_file_path = inspect.getfile(component)
            is_chart_demo = "/src/docs/library/charts/" in component_file_path

            return demo_and_code_single_file_wrapper(
                component(), source_code, is_chart_demo
            )

        except (ValueError, SyntaxError):
            return render_parse_error(
                msg="Error parsing arguments. Ensure they are in a valid format."
            )

    def _handle_demo_and_single_function(self, argument: str | None) -> rx.Component:
        if not argument:
            return render_parse_error(
                msg="Missing arguments for demo_and_single_function"
            )

        arg_lower = argument.lower()
        try:
            if not isinstance(arg_lower, str):
                return render_parse_error(
                    msg="Invalid argument format. Expected a string. Example: function_name"
                )

            if arg_lower not in self.components_registry:
                return render_parse_error(
                    msg=f"Missing component for demo_and_single_function: {argument}"
                )

            component = self.components_registry[arg_lower]
            source_code = inspect.getsource(component)
            component_file_path = inspect.getfile(component)
            is_chart_demo = "/src/docs/library/charts/" in component_file_path

            return demo_and_code_single_file_wrapper(
                component(), source_code, is_chart_demo
            )

        except (ValueError, SyntaxError):
            return render_parse_error(
                msg="Error parsing arguments. Ensure they are in a valid format."
            )



import reflex as rx

from ...base_ui.components.base.collapsible import collapsible
from ...base_ui.components.base.button import button


def collapsible_example():
    return collapsible(
        trigger=button(
            "Trigger",
            varient="outline",
            class_name="w-full",
        ),
        content=rx.el.p(
            "This is the collapsible content. You can put anything here!",
            class_name="py-2 text-center",
        ),
        default_open=False,
        class_name="w-full max-w-xs",
    )



import reflex as rx

from src.docs.library.charts.util import (
    info,
    get_tooltip,
)


def radar_v6():
    stats = [
        {"category": "Farming", "score": 7},
        {"category": "Fighting", "score": 6},
        {"category": "Aggressiveness", "score": 7},
        {"category": "Map Awareness", "score": 6},
        {"category": "Objective Control", "score": 6},
        {"category": "Positioning", "score": 7},
    ]

    return rx.box(
        info(
            "Radar Chart - Filled Grid",
            "3",
            "Player performance across key gameplay categories",
            "center",
        ),
        rx.recharts.radar_chart(
            get_tooltip(),
            rx.recharts.polar_grid(
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300 fill-[gray] opacity-20",
                    "text-sm stroke-gray-700 fill-[gray] opacity-20",
                ),
                grid_type="circle",
            ),
            rx.recharts.polar_angle_axis(
                data_key="category",
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300",
                    "text-sm stroke-gray-700",
                ),
                axis_line_type="circle",
            ),
            rx.recharts.radar(
                data_key="score",
                dot=False,
                fill="var(--chart-1)",
                stroke="none",
            ),
            data=stats,
            width="100%",
            height=250,
            margin={"left": 20, "right": 20},
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "Performance trends in key gameplay categories",
            "center",
        ),
        class_name="w-full flex flex-col gap-y-4 p-1 items-center [&_.recharts-tooltip-item-separator]:w-full",
    )



from reflex.components.el import Input
from reflex.components.component import ComponentNamespace

INPUT = (
    "file:text-[var(--foreground)] placeholder:text-[var(--muted-foreground)] "
    "selection:bg-[var(--primary)] selection:text-[var(--primary-foreground)] "
    "dark:bg-[var(--input)]/30 border-[var(--input)] "
    "h-9 w-full min-w-0 rounded-md border bg-transparent px-3 py-1 text-base shadow-xs "
    "transition-[color,box-shadow] outline-none "
    "file:inline-flex file:h-7 file:border-0 file:bg-transparent file:text-sm file:font-medium "
    "disabled:pointer-events-none disabled:cursor-not-allowed disabled:opacity-50 "
    "md:text-sm "
    "focus-visible:border-[var(--ring)] focus-visible:ring-[var(--ring)]/50 focus-visible:ring-[3px] "
    "aria-invalid:ring-[var(--destructive)]/20 dark:aria-invalid:ring-[var(--destructive)]/40 "
    "aria-invalid:border-[var(--destructive)]"
)


class InputComponent(Input):
    """Styled input component that extends rx.el.input."""

    @classmethod
    def create(cls, *children, **props):
        """Create the input component with default styling."""
        # Get existing class_name or empty string
        existing_class = props.get("class_name", "")

        # Merge base classes with any custom classes
        props["class_name"] = f"{INPUT} {existing_class}".strip()

        # Set data slot
        props["data_slot"] = "input"

        # Set default type if not provided
        if "type" not in props:
            props["type"] = "text"

        return super().create(*children, **props)


class Input(ComponentNamespace):
    """Namespace for Input component."""

    __call__ = staticmethod(InputComponent.create)


input = Input()



"""Custom skeleton component."""

from reflex.components.component import Component
from reflex.components.el import Div
from reflex.vars.base import Var

from ...utils.twmerge import cn


class ClassNames:
    """Class names for skeleton component."""

    ROOT = "animate-pulse bg-secondary"


def skeleton_component(
    class_name: str | Var[str] = "",
) -> Component:
    """Skeleton component."""
    return Div.create(class_name=cn(ClassNames.ROOT, class_name))


skeleton = skeleton_component



"""Typed component wrapper for react-typed."""

import reflex as rx
from reflex.utils.imports import ImportVar


class Typed(rx.Component):
    """Typed component for typewriter animation effects."""

    # Use the maintained fork instead of the buggy react-typed
    library = "react-typed"
    tag = "ReactTyped"

    # Core props
    strings: rx.Var[list[str]]
    type_speed: rx.Var[int]
    back_speed: rx.Var[int]
    back_delay: rx.Var[int]
    start_delay: rx.Var[int]
    loop: rx.Var[bool]
    loop_count: rx.Var[int]
    show_cursor: rx.Var[bool]
    cursor_char: rx.Var[str]
    smart_backspace: rx.Var[bool]
    shuffle: rx.Var[bool]
    fade_out: rx.Var[bool]
    fade_out_delay: rx.Var[int]
    stopped: rx.Var[bool]

    @classmethod
    def create(cls, **props):
        """Create a Typed component.

        Args:
            **props: Component props like strings, type_speed, etc.

        Returns:
            The component instance.
        """
        return super().create(**props)

    def add_imports(self) -> rx.ImportDict:
        """Add the Typed component import."""
        return {self.library: ImportVar(tag=self.tag, is_default=False)}


def typed(**props) -> rx.Component:
    """Create a typewriter animation component.

    NOTE: This uses react-typed-component (maintained fork).
    Install with: npm install react-typed-component

    Args:
        strings: List of strings to type out
        type_speed: Typing speed in milliseconds (default: 0)
        back_speed: Backspacing speed in milliseconds (default: 0)
        back_delay: Time before backspacing in milliseconds (default: 700)
        start_delay: Time before typing starts in milliseconds (default: 0)
        loop: Whether to loop the animation (default: False)
        loop_count: Number of times to loop, 0 = infinite (default: 0)
        show_cursor: Show blinking cursor (default: True)
        cursor_char: Character to use for cursor (default: "|")
        smart_backspace: Only backspace what doesn't match previous string (default: True)
        shuffle: Shuffle the strings (default: False)
        fade_out: Fade out instead of backspace (default: False)
        fade_out_delay: Delay before fade out in milliseconds (default: 500)
        stopped: Stop the animation (default: False)
        **props: Additional component props

    Returns:
        The Typed component.
    """
    return Typed.create(**props)



import reflex as rx
from ...base_ui.components.base.dialog import dialog
from ...base_ui.components.base.button import button
from ...base_ui.components.base.input import input


def dialog_hh():
    return dialog(
        trigger=button("Open Dialog", variant="outline"),
        title="Are you absolutely sure?",
        description="This action cannot be undone. This will permanently delete your account and remove your data from our servers.",
        content=rx.flex(
            button("Cancel", variant="outline", class_name="flex-1"),
            button("Continue", class_name="flex-1"),
            class_name="flex gap-2 w-full",
        ),
    )


def dialog_ll():
    return dialog.root(
        # Trigger button
        dialog.trigger(
            render_=button("Open Dialog"),
        ),
        # Portal with backdrop and popup
        dialog.portal(
            dialog.backdrop(),
            dialog.popup(
                # Header section
                rx.box(
                    rx.flex(
                        dialog.title("Edit Profile"),
                        dialog.close(
                            render_=button(
                                rx.icon("x", class_name="size-4"),
                                variant="ghost",
                                size="icon-sm",
                                class_name="text-secondary-11",
                            ),
                        ),
                        class_name="flex justify-between items-baseline gap-1",
                    ),
                    dialog.description(
                        "Make changes to your profile here. Click save when you're done."
                    ),
                    class_name="flex flex-col gap-2",
                ),
                # Content section
                rx.box(
                    rx.box(
                        rx.text("Name", class_name="text-sm font-medium mb-2"),
                        input(placeholder="Enter your name"),
                    ),
                    rx.box(
                        rx.text("Email", class_name="text-sm font-medium mb-2"),
                        input(placeholder="Enter your email", type="email"),
                    ),
                    rx.flex(
                        dialog.close(
                            render_=button(
                                "Cancel", variant="outline", class_name="flex-1"
                            ),
                        ),
                        button("Save Changes", class_name="flex-1"),
                        class_name="flex gap-2 w-full",
                    ),
                    class_name="flex flex-col gap-4",
                ),
            ),
        ),
    )



import re
import inspect
import pathlib
import importlib
import sys
import ast
import shutil

# Add the project root to the Python path to allow imports from 'src'
ROOT_DIR = pathlib.Path(__file__).parent.parent
sys.path.append(str(ROOT_DIR))

# --- PATHS ---
DOCS_SOURCE_DIR = ROOT_DIR / "docs"
MARKDOWN_OUTPUT_DIR = ROOT_DIR / "assets" / "docs"  # Updated output directory
COMPONENTS_LIBRARY_DIR = ROOT_DIR / "src" / "docs" / "library"


def dynamic_load_components(directory: pathlib.Path) -> dict:
    """
    Dynamically loads component functions and classes from a given directory
    and its subdirectories.
    """
    registry = {}
    for py_file in directory.rglob("*.py"):
        if py_file.name.startswith("__"):
            continue

        relative_py_file = py_file.relative_to(ROOT_DIR)
        module_path = ".".join(relative_py_file.with_suffix("").parts)

        try:
            module = importlib.import_module(module_path)
            for name, obj in inspect.getmembers(module):
                if (
                    inspect.isfunction(obj) or inspect.isclass(obj)
                ) and obj.__module__ == module.__name__:
                    registry[name.lower()] = obj
        except Exception as e:
            print(
                f"Warning: Could not import from module {module_path}. Error: {e}",
                file=sys.stderr,
            )
    return registry


def get_source_code(
    command: str, argument: str | None, registry: dict
) -> tuple[str, str] | None:
    """
    Retrieves the source code for a component based on the parsed command and argument.
    Returns a tuple of (code, language) or None if not found.
    """
    command_lower = command.lower()
    arg_lower = argument.lower() if argument else None

    func_name = None
    language = "python"

    if command_lower in [
        "demo_and_single_function",
        "full_source_page_of_component",
    ]:
        func_name = arg_lower
    elif command_lower == "show_code_with_language":
        try:
            args = ast.literal_eval(argument)
            if isinstance(args, list) and len(args) > 0:
                func_name = args[0].lower()
                if len(args) > 1 and args[1]:
                    language = args[1]
        except (ValueError, SyntaxError) as e:
            print(
                f"Warning: Could not parse argument for SHOW_CODE_WITH_LANGUAGE: {argument}. Error: {e}",
                file=sys.stderr,
            )
            return None
    elif arg_lower is None and command_lower in registry:
        func_name = command_lower

    if not func_name or func_name not in registry:
        return None

    func_obj = registry[func_name]

    try:
        if command_lower == "full_source_page_of_component":
            source_file = inspect.getfile(func_obj)
            code = pathlib.Path(source_file).read_text()
        else:
            code = inspect.getsource(func_obj)
        return code, language
    except Exception as e:
        print(
            f"Warning: Could not get source for '{func_name}'. Error: {e}",
            file=sys.stderr,
        )

    return None


def convert_to_pure_markdown(content: str, registry: dict) -> str:
    """
    Replaces custom component delimiters in markdown content with formatted code blocks.
    """
    delimiter_pattern = r"--([\w_]+)(?:\((.*)\))?--"

    def replacer(match):
        command = match.group(1)
        argument = match.group(2)

        if command.lower() == "cli_and_manual_installation":
            if not argument:
                return "Error: Missing argument for CLI_AND_MANUAL_INSTALLATION"

            try:
                args = ast.literal_eval(argument)
                if not isinstance(args, list) or len(args) != 2:
                    return (
                        "Error: Invalid argument format for CLI_AND_MANUAL_INSTALLATION"
                    )

                component_name, cli_command = args
                component_name_lower = component_name.lower()

                if component_name_lower not in registry:
                    return f"Error: Component '{component_name}' not found in registry."

                func = registry[component_name_lower]
                source_file = inspect.getfile(func)
                source_code = pathlib.Path(source_file).read_text()

                cli_section = f"### CLI\n\n```bash\n{cli_command}\n```"
                manual_section = (
                    f"### Manual Installation\n\n```python\n{source_code.strip()}\n```"
                )

                return f"\n{cli_section}\n\n{manual_section}\n"

            except (ValueError, SyntaxError, IndexError) as e:
                return f"Error parsing arguments for CLI_AND_MANUAL_INSTALLATION: {e}"
            except Exception as e:
                return f"Error processing CLI_AND_MANUAL_INSTALLATION: {e}"

        # Fallback to old logic for other commands
        source_info = get_source_code(command, argument, registry)
        if source_info:
            code, language = source_info
            return f"\n```{language}\n{code.strip()}\n```\n"
        return ""

    if content.startswith("---"):
        parts = content.split("---", 2)
        if len(parts) > 2:
            content = parts[2]

    return re.sub(delimiter_pattern, replacer, content)


def main():
    """Main function to generate pure markdown files from the docs directory."""
    print("Starting markdown generation process...")

    # Clean up old output directories
    print("Cleaning up old output directories...")
    dirs_to_clean = [
        ROOT_DIR / "markdown",
        ROOT_DIR / "assets" / "markdown",
        MARKDOWN_OUTPUT_DIR,
    ]
    for d in dirs_to_clean:
        if d.exists():
            shutil.rmtree(d)
            print(f"Removed old directory: {d}")

    # Load components
    print(f"Loading components from: {COMPONENTS_LIBRARY_DIR}")
    component_registry = dynamic_load_components(COMPONENTS_LIBRARY_DIR)
    print(f"Successfully loaded {len(component_registry)} components.")

    # Ensure output directory exists
    MARKDOWN_OUTPUT_DIR.mkdir(parents=True, exist_ok=True)
    print(f"Output directory set to: {MARKDOWN_OUTPUT_DIR}")

    # Process markdown files
    print(f"Processing markdown files from: {DOCS_SOURCE_DIR}")
    file_count = 0
    for md_file in DOCS_SOURCE_DIR.rglob("*.md"):
        file_count += 1
        original_content = md_file.read_text()
        pure_md_content = convert_to_pure_markdown(original_content, component_registry)

        # Create new path with hyphens
        relative_path = md_file.relative_to(DOCS_SOURCE_DIR)
        hyphenated_parts = [part.replace("_", "-") for part in relative_path.parts]
        hyphenated_relative_path = pathlib.Path(*hyphenated_parts)
        output_path = MARKDOWN_OUTPUT_DIR / hyphenated_relative_path

        output_path.parent.mkdir(parents=True, exist_ok=True)
        output_path.write_text(pure_md_content)

        print(f"Processed: {md_file.relative_to(ROOT_DIR)}. Status: OK")

    print(f"\nMarkdown generation complete. Processed {file_count} files.")


if __name__ == "__main__":
    main()



import reflex as rx

from src.templates.sidebar import sidebar
from src.templates.navbar import main_navbar


def docpage(main_content, toc_content):
    """The template for all documentation pages."""
    return rx.el.body(
        rx.el.div(
            rx.el.header(main_navbar(), class_name="sticky top-0 z-50"),
            rx.el.main(
                rx.el.div(
                    sidebar(),
                    rx.el.div(
                        rx.el.div(
                            main_content,
                            class_name="flex-1 min-w-0 py-6",
                        ),
                        toc_content,
                        class_name="flex items-start w-full flex-1 min-w-0",
                    ),
                    class_name="flex w-full gap-x-0 xl:max-w-[80rem] 2xl:max-w-[85rem] mx-auto",
                ),
                class_name="w-full",
            ),
            class_name="bg-background relative flex min-h-screen flex-col",
        ),
    )



"""Custom context menu component."""

from typing import Literal

from reflex.components.component import Component, ComponentNamespace
from reflex.components.core.foreach import foreach
from reflex.event import EventHandler, passthrough_event_spec
from reflex.utils.imports import ImportVar
from reflex.vars.base import Var

from .button import button
from ..base_ui import PACKAGE_NAME, BaseUIComponent
from ...utils.twmerge import cn

LiteralOpenChangeReason = Literal[
    "arrowKey",
    "escapeKey",
    "select",
    "hover",
    "click",
    "focus",
    "dismiss",
    "typeahead",
    "tab",
]
LiteralMenuOrientation = Literal["vertical", "horizontal"]
LiteralSide = Literal["top", "right", "bottom", "left"]
LiteralAlign = Literal["start", "center", "end"]
LiteralPositionMethod = Literal["absolute", "fixed"]
LiteralCollisionAvoidance = Literal["flip", "shift", "auto"]
LiteralMenuSize = Literal["xs", "sm", "md", "lg", "xl"]


class ClassNames:
    """Class names for context menu components."""

    TRIGGER = ""
    PORTAL = ""
    BACKDROP = "fixed inset-0"
    POPUP = "z-50 max-h-(--radix-context-menu-content-available-height) min-w-[8rem] origin-(--radix-context-menu-content-transform-origin) overflow-x-hidden overflow-y-auto rounded-md border border-input p-1 shadow-md bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2"
    ITEM = "relative flex cursor-default items-center gap-2 rounded-sm px-2 py-1.5 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 focus:bg-accent focus:text-accent-foreground [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4 [&_svg:not([class*='text-'])]:text-muted-foreground"
    ITEM_INDICATOR = "text-current"
    ITEM_TEXT = "text-start"
    SEPARATOR = "bg-border -mx-1 my-1 h-px"
    ARROW = "data-[side=bottom]:top-[-8px] data-[side=left]:right-[-13px] data-[side=left]:rotate-90 data-[side=right]:left-[-13px] data-[side=right]:-rotate-90 data-[side=top]:bottom-[-8px] data-[side=top]:rotate-180"
    POSITIONER = "outline-none"
    GROUP = ""
    GROUP_LABEL = "text-foreground px-2 py-1.5 text-sm font-medium"
    RADIO_GROUP = ""
    RADIO_ITEM = "relative flex cursor-default items-center gap-2 rounded-sm py-1.5 pr-2 pl-8 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 focus:bg-accent focus:text-accent-foreground [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4"
    RADIO_ITEM_INDICATOR = (
        "absolute left-2 flex size-3.5 items-center justify-center pointer-events-none"
    )
    CHECKBOX_ITEM = "relative flex cursor-default items-center gap-2 rounded-sm py-1.5 pr-2 pl-8 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 focus:bg-accent focus:text-accent-foreground [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4"
    CHECKBOX_ITEM_INDICATOR = (
        "absolute left-2 flex size-3.5 items-center justify-center pointer-events-none"
    )
    SUBMENU_TRIGGER = "relative flex cursor-default items-center gap-2 rounded-sm px-2 py-1.5 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 focus:bg-accent focus:text-accent-foreground data-[state=open]:bg-accent data-[state=open]:text-accent-foreground [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4 [&_svg:not([class*='text-'])]:text-muted-foreground"


class ContextMenuBaseComponent(BaseUIComponent):
    """Base component for context menu components."""

    library = f"{PACKAGE_NAME}/context-menu"

    @property
    def import_var(self):
        """Return the import variable for the context menu component."""
        return ImportVar(tag="ContextMenu", package_path="", install=False)


class ContextMenuRoot(ContextMenuBaseComponent):
    """Groups all parts of the context menu. Doesn't render its own HTML element."""

    tag = "ContextMenu.Root"

    # Whether the context menu is initially open. To render a controlled context menu, use the open prop instead. Defaults to False.
    default_open: Var[bool]

    # Whether the context menu is currently open.
    open: Var[bool]

    # Event handler called when the context menu is opened or closed.
    on_open_change: EventHandler[passthrough_event_spec(bool, dict)]

    # A ref to imperative actions. When specified, the context menu will not be unmounted when closed. Instead, the unmount function must be called to unmount the context menu manually. Useful when the context menu's animation is controlled by an external library.
    actions_ref: Var[str]

    # When in a submenu, determines whether pressing the Escape key closes the entire menu, or only the current child menu. Defaults to True.
    close_parent_on_esc: Var[bool]

    # Event handler called after any animations complete when the context menu is closed.
    on_open_change_complete: EventHandler[passthrough_event_spec(bool)]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # Whether keyboard navigation should loop around when reaching the end of the items. Defaults to True.
    loop: Var[bool]

    # The visual orientation of the menu. Controls whether roving focus uses up/down or left/right arrow keys. Defaults to "vertical".
    orientation: Var[LiteralMenuOrientation]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu root component."""
        props["data-slot"] = "context-menu"
        return super().create(*children, **props)


class ContextMenuTrigger(ContextMenuBaseComponent):
    """An area that opens the context menu on right click or long press. Renders a <div> element."""

    tag = "ContextMenu.Trigger"

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu trigger component."""
        props["data-slot"] = "context-menu-trigger"
        cls.set_class_name(ClassNames.TRIGGER, props)
        return super().create(*children, **props)


class ContextMenuPortal(ContextMenuBaseComponent):
    """A portal element that moves the popup to a different part of the DOM. By default, the portal element is appended to <body>."""

    tag = "ContextMenu.Portal"

    # A parent element to render the portal element into. Defaults to document.body.
    container: Var[str]

    # Whether to keep the portal mounted in the DOM while the popup is hidden. Defaults to False.
    keep_mounted: Var[bool]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu portal component."""
        props["data-slot"] = "context-menu-portal"
        cls.set_class_name(ClassNames.PORTAL, props)
        return super().create(*children, **props)


class ContextMenuBackdrop(ContextMenuBaseComponent):
    """A backdrop element that covers the entire viewport when the context menu is open. Renders a <div> element."""

    tag = "ContextMenu.Backdrop"

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu backdrop component."""
        props["data-slot"] = "context-menu-backdrop"
        cls.set_class_name(ClassNames.BACKDROP, props)
        return super().create(*children, **props)


class ContextMenuPositioner(ContextMenuBaseComponent):
    """Positions the context menu popup against the trigger. Renders a <div> element."""

    tag = "ContextMenu.Positioner"

    # Determines how to handle collisions when positioning the popup.
    collision_avoidance: Var[LiteralCollisionAvoidance]

    # How to align the popup relative to the specified side. Defaults to "center".
    align: Var[LiteralAlign]

    # Additional offset along the alignment axis in pixels. Defaults to 0.
    align_offset: Var[int]

    # Which side of the anchor element to align the popup against. May automatically change to avoid collisions. Defaults to "bottom".
    side: Var[LiteralSide]

    # Distance between the anchor and the popup in pixels. Defaults to 0.
    side_offset: Var[int]

    # Minimum distance to maintain between the arrow and the edges of the popup. Defaults to 5.
    arrow_padding: Var[int]

    # Additional space to maintain from the edge of the collision boundary. Defaults to 5.
    collision_padding: Var[int]

    # An element or a rectangle that delimits the area that the popup is confined to. Defaults to "clipping-ancestors".
    collision_boundary: Var[str]

    # Whether to maintain the popup in the viewport after the anchor element was scrolled out of view. Defaults to False.
    sticky: Var[bool]

    # Whether the popup tracks any layout shift of its positioning anchor. Defaults to True.
    track_anchor: Var[bool]

    # Determines which CSS position property to use. Defaults to "absolute".
    position_method: Var[LiteralPositionMethod]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu positioner component."""
        props["data-slot"] = "context-menu-positioner"
        cls.set_class_name(ClassNames.POSITIONER, props)
        return super().create(*children, **props)


class ContextMenuPopup(ContextMenuBaseComponent):
    """A container for the context menu items. Renders a <div> element."""

    tag = "ContextMenu.Popup"

    # Determines the element to focus when the context menu is closed. By default, focus returns to the trigger.
    final_focus: Var[str]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu popup component."""
        props["data-slot"] = "context-menu-popup"
        cls.set_class_name(ClassNames.POPUP, props)
        return super().create(*children, **props)


class ContextMenuArrow(ContextMenuBaseComponent):
    """Displays an element positioned against the context menu anchor. Renders a <div> element."""

    tag = "ContextMenu.Arrow"

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu arrow component."""
        props["data-slot"] = "context-menu-arrow"
        cls.set_class_name(ClassNames.ARROW, props)
        return super().create(*children, **props)


class ContextMenuItem(ContextMenuBaseComponent):
    """An individual interactive item in the context menu. Renders a <div> element."""

    tag = "ContextMenu.Item"

    # Overrides the text label to use when the item is matched during keyboard text navigation.
    label: Var[str]

    # Whether to close the context menu when the item is clicked. Defaults to True.
    close_on_click: Var[bool]

    # Whether the component renders a native button element when replacing it via the render prop. Set to true if the rendered element is a native button. Defaults to False.
    native_button: Var[bool]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu item component."""
        props["data-slot"] = "context-menu-item"
        cls.set_class_name(ClassNames.ITEM, props)
        return super().create(*children, **props)


class ContextMenuSeparator(ContextMenuBaseComponent):
    """A separator element accessible to screen readers. Renders a <div> element."""

    tag = "ContextMenu.Separator"

    # The orientation of the separator. Defaults to "horizontal".
    orientation: Var[LiteralMenuOrientation]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu separator component."""
        props["data-slot"] = "context-menu-separator"
        cls.set_class_name(ClassNames.SEPARATOR, props)
        return super().create(*children, **props)


class ContextMenuGroup(ContextMenuBaseComponent):
    """Groups related context menu items with the corresponding label. Renders a <div> element."""

    tag = "ContextMenu.Group"

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu group component."""
        props["data-slot"] = "context-menu-group"
        cls.set_class_name(ClassNames.GROUP, props)
        return super().create(*children, **props)


class ContextMenuGroupLabel(ContextMenuBaseComponent):
    """An accessible label that is automatically associated with its parent group. Renders a <div> element."""

    tag = "ContextMenu.GroupLabel"

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu group label component."""
        props["data-slot"] = "context-menu-group-label"
        cls.set_class_name(ClassNames.GROUP_LABEL, props)
        return super().create(*children, **props)


class ContextMenuRadioGroup(ContextMenuBaseComponent):
    """Groups related radio items. Renders a <div> element."""

    tag = "ContextMenu.RadioGroup"

    # The uncontrolled value of the radio item that should be initially selected. To render a controlled radio group, use the value prop instead.
    default_value: Var[str | int]

    # The controlled value of the radio group.
    value: Var[str | int]

    # Event handler called when the value changes.
    on_value_change: EventHandler[passthrough_event_spec(str | int, dict)]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu radio group component."""
        props["data-slot"] = "context-menu-radio-group"
        cls.set_class_name(ClassNames.RADIO_GROUP, props)
        return super().create(*children, **props)


class ContextMenuRadioItem(ContextMenuBaseComponent):
    """A context menu item that works like a radio button in a given group. Renders a <div> element."""

    tag = "ContextMenu.RadioItem"

    # Overrides the text label to use when the item is matched during keyboard text navigation.
    label: Var[str]

    value: Var[str | int]

    # Whether to close the context menu when the item is clicked. Defaults to False.
    close_on_click: Var[bool]

    # Whether the component renders a native button element when replacing it via the render prop. Set to true if the rendered element is a native button. Defaults to False.
    native_button: Var[bool]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu radio item component."""
        props["data-slot"] = "context-menu-radio-item"
        cls.set_class_name(ClassNames.RADIO_ITEM, props)
        return super().create(*children, **props)


class ContextMenuRadioItemIndicator(ContextMenuBaseComponent):
    """Indicates whether the radio item is selected. Renders a <div> element."""

    tag = "ContextMenu.RadioItemIndicator"

    # Whether to keep the indicator mounted in the DOM when the radio item is not checked. Defaults to False.
    keep_mounted: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu radio item indicator component."""
        props["data-slot"] = "context-menu-radio-item-indicator"
        cls.set_class_name(ClassNames.RADIO_ITEM_INDICATOR, props)
        return super().create(*children, **props)


class ContextMenuCheckboxItem(ContextMenuBaseComponent):
    """A context menu item that toggles a setting on or off. Renders a <div> element."""

    tag = "ContextMenu.CheckboxItem"

    # Overrides the text label to use when the item is matched during keyboard text navigation.
    label: Var[str]

    # Whether the checkbox item is initially checked. To render a controlled checkbox item, use the checked prop instead. Defaults to False.
    default_checked: Var[bool]

    # Whether the checkbox item is currently checked. To render an uncontrolled checkbox item, use the default_checked prop instead.
    checked: Var[bool]

    # Event handler called when the checkbox item is ticked or unticked.
    on_checked_change: EventHandler[passthrough_event_spec(bool, dict)]

    # Whether to close the context menu when the item is clicked. Defaults to False.
    close_on_click: Var[bool]

    # Whether the component renders a native button element when replacing it via the render prop. Set to true if the rendered element is a native button. Defaults to False.
    native_button: Var[bool]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu checkbox item component."""
        props["data-slot"] = "context-menu-checkbox-item"
        cls.set_class_name(ClassNames.CHECKBOX_ITEM, props)
        return super().create(*children, **props)


class ContextMenuCheckboxItemIndicator(ContextMenuBaseComponent):
    """Indicates whether the checkbox item is ticked. Renders a <div> element."""

    tag = "ContextMenu.CheckboxItemIndicator"

    # Whether to keep the indicator mounted in the DOM when the checkbox item is not checked. Defaults to False.
    keep_mounted: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu checkbox item indicator component."""
        props["data-slot"] = "context-menu-checkbox-item-indicator"
        cls.set_class_name(ClassNames.CHECKBOX_ITEM_INDICATOR, props)
        return super().create(*children, **props)


class ContextMenuSubmenuRoot(ContextMenuBaseComponent):
    """Groups all parts of a submenu. Doesn't render its own HTML element."""

    tag = "ContextMenu.SubmenuRoot"

    # Whether the submenu is initially open. To render a controlled submenu, use the open prop instead. Defaults to False.
    default_open: Var[bool]

    # Whether the submenu is currently open.
    open: Var[bool]

    # Event handler called when the submenu is opened or closed.
    on_open_change: EventHandler[passthrough_event_spec(bool, dict)]

    # When in a submenu, determines whether pressing the Escape key closes the entire menu, or only the current child menu. Defaults to True.
    close_parent_on_esc: Var[bool]

    # Event handler called after any animations complete when the submenu is closed.
    on_open_change_complete: EventHandler[passthrough_event_spec(bool)]

    # Whether the component should ignore user interaction. Defaults to False.
    disabled: Var[bool]

    # Whether the submenu should also open when the trigger is hovered. Defaults to True.
    open_on_hover: Var[bool]

    # How long to wait before the submenu may be opened on hover. Specified in milliseconds. Requires the open_on_hover prop. Defaults to 100.
    delay: Var[int]

    # How long to wait before closing the submenu that was opened on hover. Specified in milliseconds. Requires the open_on_hover prop. Defaults to 0.
    close_delay: Var[int]

    # Whether to loop keyboard focus back to the first item when the end of the list is reached while using the arrow keys. Defaults to True.
    loop: Var[bool]

    # The visual orientation of the submenu. Controls whether roving focus uses up/down or left/right arrow keys. Defaults to "vertical".
    orientation: Var[LiteralMenuOrientation]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu submenu root component."""
        props["data-slot"] = "context-menu-submenu-root"
        return super().create(*children, **props)


class ContextMenuSubmenuTrigger(ContextMenuBaseComponent):
    """A context menu item that opens a submenu."""

    tag = "ContextMenu.SubmenuTrigger"

    # Overrides the text label to use when the item is matched during keyboard text navigation.
    label: Var[str]

    # Whether the component renders a native button element when replacing it via the render prop. Set to true if the rendered element is a native button. Defaults to False.
    native_button: Var[bool]

    # The render prop.
    render_: Var[Component]

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create the context menu submenu trigger component."""
        props["data-slot"] = "context-menu-submenu-trigger"
        cls.set_class_name(ClassNames.SUBMENU_TRIGGER, props)
        return super().create(*children, **props)


class HighLevelContextMenu(ContextMenuRoot):
    """High level wrapper for the ContextMenu component."""

    # The trigger component to use for the context menu
    trigger: Var[Component | None]

    # The list of items to display in the context menu - can be strings or tuples of (label, on_click_handler)
    items: Var[list[str | tuple[str, EventHandler]]]

    # The size of the context menu. Defaults to "md".
    size: Var[LiteralMenuSize]

    # Props for different component parts
    _item_props = {"close_on_click"}
    _positioner_props = {
        "align",
        "align_offset",
        "side",
        "arrow_padding",
        "collision_padding",
        "sticky",
        "position_method",
        "track_anchor",
        "side_offset",
        "collision_avoidance",
        "collision_boundary",
    }
    _portal_props = {"container", "keep_mounted"}

    @classmethod
    def create(cls, *children, **props) -> BaseUIComponent:
        """Create a context menu component.

        Args:
            *children: Additional children to include in the context menu.
            **props: Additional properties to apply to the context menu component.

        Returns:
            The context menu component.
        """
        # Extract props for different parts
        item_props = {k: props.pop(k) for k in cls._item_props & props.keys()}
        positioner_props = {
            k: props.pop(k) for k in cls._positioner_props & props.keys()
        }
        portal_props = {k: props.pop(k) for k in cls._portal_props & props.keys()}

        trigger = props.pop("trigger", None)
        items = props.pop("items", [])
        size = props.pop("size", "md")

        def create_context_menu_item(
            item: str | tuple[str, EventHandler],
        ) -> BaseUIComponent:
            if isinstance(item, tuple):
                label, on_click_handler = item
                return ContextMenuItem.create(
                    render_=button(
                        label,
                        variant="ghost",
                        class_name=ClassNames.ITEM,
                        disabled=props.get("disabled", False),
                        on_click=on_click_handler,
                        size=size,
                        type="button",
                    ),
                    key=label,
                    **item_props,
                )
            return ContextMenuItem.create(
                render_=button(
                    item,
                    variant="ghost",
                    class_name=ClassNames.ITEM,
                    disabled=props.get("disabled", False),
                    size=size,
                    type="button",
                ),
                key=item,
                **item_props,
            )

        if isinstance(items, Var):
            items_children = foreach(items, create_context_menu_item)
        else:
            items_children = [create_context_menu_item(item) for item in items]

        return ContextMenuRoot.create(
            (
                ContextMenuTrigger.create(
                    render_=trigger,
                )
                if trigger
                else None
            ),
            ContextMenuPortal.create(
                ContextMenuPositioner.create(
                    ContextMenuPopup.create(
                        items_children,
                        *children,
                        class_name=cn(
                            ClassNames.POPUP,
                            "",
                            # f"rounded-[calc(var(--radius-ui-{size})+0.25rem)]",
                        ),
                    ),
                    **positioner_props,
                ),
                **portal_props,
            ),
            **props,
        )

    def _exclude_props(self) -> list[str]:
        return [
            *super()._exclude_props(),
            "trigger",
            "items",
            "size",
        ]


class ContextMenu(ComponentNamespace):
    """Namespace for ContextMenu components."""

    root = staticmethod(ContextMenuRoot.create)
    trigger = staticmethod(ContextMenuTrigger.create)
    portal = staticmethod(ContextMenuPortal.create)
    backdrop = staticmethod(ContextMenuBackdrop.create)
    positioner = staticmethod(ContextMenuPositioner.create)
    popup = staticmethod(ContextMenuPopup.create)
    arrow = staticmethod(ContextMenuArrow.create)
    item = staticmethod(ContextMenuItem.create)
    separator = staticmethod(ContextMenuSeparator.create)
    group = staticmethod(ContextMenuGroup.create)
    group_label = staticmethod(ContextMenuGroupLabel.create)
    radio_group = staticmethod(ContextMenuRadioGroup.create)
    radio_item = staticmethod(ContextMenuRadioItem.create)
    radio_item_indicator = staticmethod(ContextMenuRadioItemIndicator.create)
    checkbox_item = staticmethod(ContextMenuCheckboxItem.create)
    checkbox_item_indicator = staticmethod(ContextMenuCheckboxItemIndicator.create)
    submenu_root = staticmethod(ContextMenuSubmenuRoot.create)
    submenu_trigger = staticmethod(ContextMenuSubmenuTrigger.create)
    class_names = ClassNames
    __call__ = staticmethod(HighLevelContextMenu.create)


context_menu = ContextMenu()



import reflex as rx
from ...base_ui.components.base.skeleton import skeleton_component


def skeleton_example():
    """A basic skeleton example."""
    return skeleton_component(class_name="h-8 w-32 rounded-md")


def skeleton_card_example():
    """A skeleton example simulating a loading card."""
    return rx.box(
        rx.flex(
            skeleton_component(class_name="h-12 w-12 rounded-full"),
            rx.flex(
                skeleton_component(class_name="h-4 w-[250px] rounded-md"),
                skeleton_component(class_name="h-4 w-[200px] rounded-md"),
                direction="column",
                spacing="2",
            ),
            spacing="4",
        ),
        class_name="flex items-center space-x-4 rounded-md border border-input p-4 w-96",
    )



import reflex as rx
from reflex.experimental import ClientStateVar
from dataclasses import dataclass  # Added for Session class placeholder


# Placeholder for Session class used in Complex Example
@dataclass
class Session:
    session_id: str
    name: str
    blocks: list  # Assuming blocks is a list, adjust as needed

    def copy(self, update: dict):
        # Simple copy for demonstration
        new_session = Session(self.session_id, self.name, self.blocks)
        if "name" in update:
            new_session.name = update["name"]
        return new_session


# Used in --show_code(tab_navigation_example)--
def tab_navigation_example():
    # Create the client state variable
    ActiveTab = ClientStateVar.create("tab_v1", 0)
    TabList = ["GitHub", "Twitter", "YouTube"]

    return rx.box(
        rx.hstack(
            rx.foreach(
                TabList,
                lambda tab, i: rx.button(
                    rx.text(
                        tab,
                        color=rx.cond(
                            ActiveTab.value == i,
                            rx.color("slate", 12),
                            rx.color("slate", 10),
                        ),
                    ),
                    on_click=ActiveTab.set_value(i),
                    background=rx.cond(
                        ActiveTab.value == i,
                        rx.color("gray", 3),
                        "transparent",
                    ),
                    border_radius=rx.cond(ActiveTab.value == i, "0.375rem", "0.5rem"),
                    padding="0.5rem 0.75rem",
                    cursor="pointer",
                ),
            ),
            style={
                "display": "inline-flex",
                "height": "2.125rem",
                "align_items": "baseline",
                "border_radius": "0.5rem",
                "padding": "0.25rem",
                "border": f"1.25px dashed {rx.color('gray', 4)}",
            },
        )
    )


# Used in --show_code(toggle_pattern_example)--
def toggle_pattern_example():
    is_visible = ClientStateVar.create("visibility", False)

    return rx.fragment(
        # Toggle with current value
        rx.button("Toggle", on_click=is_visible.set_value(~is_visible.value)),
        # Or use a more explicit approach
        rx.button("Show", on_click=is_visible.set_value(True)),
        rx.button("Hide", on_click=is_visible.set_value(False)),
    )


# Used in --show_code(form_state_pattern_example)--
def form_state_pattern_example():
    form_state = ClientStateVar.create("form", {})

    return rx.input(
        value=form_state.value.get("username", ""),
        on_change=lambda v: form_state.set_value({**form_state.value, "username": v}),
    )


# Used in --show_code(conditional_rendering_pattern_example)--
def conditional_rendering_pattern_example():
    show_details = ClientStateVar.create("show_details", False)

    return rx.box(
        rx.button(
            "Toggle Details", on_click=show_details.set_value(~show_details.value)
        ),
        rx.cond(
            show_details.value,
            rx.div("Detailed information here..."),
            rx.div("Click to show details"),
        ),
    )



import src.routes as routes
from reflex.experimental import ClientStateVar

# Global state for selected page - default to docs overview
selected_page = ClientStateVar.create("selected_page", "docs/overview")

# Global state for switching theme of components/ui
current_theme = ClientStateVar.create("current_theme", "gray")

# Global state for search query
search_query = ClientStateVar.create("search_query", "")

# Global state for Getting Started Routes
search_items_cs = ClientStateVar.create(
    "search_items_cs",
    routes.GET_STARTED_URLS
    + routes.BASE_UI_COMPONENTS
    + routes.CHARTS_URLS
    + routes.JS_INTEGRATIONS_URLS
    + routes.WRAPPED_COMPONENTS_URLS,
)
